!******************************************************************************!
!                                                                              !
!    class_vertices.f90                                                        !
!    is part of RECOLA2 (REcursive Computation of One Loop Amplitudes)2        !
!                                                                              !
!    Copyright (C) 2016-2018 Ansgar Denner, Jean-Nicolas Lang and              !
!                            Sandro Uccirati                                   !
!                                                                              !
!    RECOLA2 is licenced under the GNU GPL version 3,                          !
!    see COPYING for details.                                                  !
!                                                                              !
!******************************************************************************!
!                                                           .---.              !
!                                                          /  .  \             !
!                                                         |\_/|   |            !
!                                                         |   |  /|            !
!          .----------------------------------------------------' |            !
!         /  .-.   class_vertices.f90                             |            !
!        |  /   \  This code was generated with REPT1L.           |            !
!        | |\_.  | Change this file and you get what you deserve. |            !
!        |\|  | /| Author: J.N. Lang                              |            !
!        | `---' | UFO date: 11/2018                              |            !
!        |       | UFO version: 1.0                               |            !
!        |       | Generation date: 2018-11-12 13:04             /             !
!        |       |----------------------------------------------'              !
!        \       |                                                             !
!         \     /                                                              !
!          `---'                                                               !
!******************************************************************************!
module class_vertices
  use fill_couplings
  use class_particles
  use class_ctparameters
  use fill_ctparameters, only: init_CTparameters_mdl
  use particle_keys, only: createParticleConfig
  use dictionary, only: dict,dict_get_value,dict_init
  use constants_mdl, only: Nc
  implicit none
  save

  interface get_vertex_mdl
    module procedure get_vertex3_mdl, get_vertex4_mdl, get_vertexN_mdl
  end interface

  type Branch
    integer :: lorentz_id
    integer :: perm
    integer, allocatable :: couplings(:)
    integer, dimension(n_orders) :: coupling_order
    integer :: color_id
    integer :: colorfac_id
    ! Propagator extension (only supported for massive vectors)
    ! 0: Usual propagator
    ! 1: Rxi-propagator part with pole @ M_V^2
    ! 2: Rxi-propagator part with pole @ \xi*M_V^2
    integer :: pext
  end type

  type Vertex
    type(Branch), allocatable :: branch(:)
    type(Branch), allocatable :: branchCT(:)
    type(Branch), allocatable :: branchR2(:)
  end type

  logical :: vertices_init = .false.
  logical :: vertices_filled = .false.
    interface createCurrent
      module procedure createCurrent2, createCurrent3, createCurrent4,         &
      createCurrent5, createCurrent6, createCurrent7, createCurrent8
    end interface 
  integer, parameter :: n_vertices = 1682
  type(Vertex) :: vertices(0:n_vertices-1)

  ! Defines the maximum allowed number of legs participating at a vertex
  integer, parameter :: max_leg_multiplicity = 4

  integer, parameter :: FFaS0 = 1
  integer, parameter :: FFaS1 = 2
  integer, parameter :: FFaS2 = 3
  integer, parameter :: VFaF0 = 4
  integer, parameter :: VFaF1 = 5
  integer, parameter :: SVVS0 = 6
  integer, parameter :: VVVV0 = 7
  integer, parameter :: VVVV1 = 8
  integer, parameter :: UaSU0 = 9
  integer, parameter :: UUaV0 = 10
  integer, parameter :: SSS0 = 11
  integer, parameter :: USUa0 = 12
  integer, parameter :: SUUa0 = 13
  integer, parameter :: VVSS0 = 14
  integer, parameter :: FaF0 = 15
  integer, parameter :: FaF1 = 16
  integer, parameter :: FFaV0 = 17
  integer, parameter :: FFaV1 = 18
  integer, parameter :: VVV0 = 19
  integer, parameter :: VVV1 = 20
  integer, parameter :: FSFa0 = 21
  integer, parameter :: FSFa1 = 22
  integer, parameter :: FSFa2 = 23
  integer, parameter :: VVS0 = 24
  integer, parameter :: FaVF0 = 25
  integer, parameter :: FaVF1 = 26
  integer, parameter :: UaVU0 = 27
  integer, parameter :: VSVS0 = 28
  integer, parameter :: FVFa0 = 29
  integer, parameter :: FVFa1 = 30
  integer, parameter :: VUaU0 = 31
  integer, parameter :: VV0 = 32
  integer, parameter :: VV1 = 33
  integer, parameter :: VV2 = 34
  integer, parameter :: SVSV0 = 35
  integer, parameter :: FaFS0 = 36
  integer, parameter :: FaFS1 = 37
  integer, parameter :: FaFS2 = 38
  integer, parameter :: FaFV0 = 39
  integer, parameter :: FaFV1 = 40
  integer, parameter :: SSSS0 = 41
  integer, parameter :: VS0 = 42
  integer, parameter :: SFFa0 = 43
  integer, parameter :: SFFa1 = 44
  integer, parameter :: SFFa2 = 45
  integer, parameter :: VUUa0 = 46
  integer, parameter :: SFaF0 = 47
  integer, parameter :: SFaF1 = 48
  integer, parameter :: SFaF2 = 49
  integer, parameter :: SVV0 = 50
  integer, parameter :: FaSF0 = 51
  integer, parameter :: FaSF1 = 52
  integer, parameter :: FaSF2 = 53
  integer, parameter :: SVS0 = 54
  integer, parameter :: FFa0 = 55
  integer, parameter :: FFa1 = 56
  integer, parameter :: VSS0 = 57
  integer, parameter :: VSV0 = 58
  integer, parameter :: SS0 = 59
  integer, parameter :: SSVV0 = 60
  integer, parameter :: SSV0 = 61
  integer, parameter :: SV0 = 62
  integer, parameter :: UUaS0 = 63
  integer, parameter :: UVUa0 = 64
  integer, parameter :: VSSV0 = 65
  integer, parameter :: UaUS0 = 66
  integer, parameter :: VFFa0 = 67
  integer, parameter :: VFFa1 = 68
  integer, parameter :: SUaU0 = 69
  integer, parameter :: UaUV0 = 70
  complex(dp), parameter :: c1 = cmplx(1d0, 0d0, kind=dp)
  character(len=20), parameter :: c1f = "1"
  complex(dp), parameter :: c2 = cmplx(sq2/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c2f = "sq2/2"
  complex(dp), parameter :: c3 = cmplx(-sq2/(2d0*Nc), 0d0, kind=dp)
  character(len=20), parameter :: c3f = "-sq2/(2*Nc)"
  complex(dp), parameter :: c4 = cmplx(0d0, sq2/2d0, kind=dp)
  character(len=20), parameter :: c4f = "i_*sq2/2"
  complex(dp), parameter :: c5 = cmplx(0d0, -sq2/2d0, kind=dp)
  character(len=20), parameter :: c5f = "-i_*sq2/2"
  complex(dp), parameter :: c6 = cmplx(1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c6f = "1/2"
  complex(dp), parameter :: c7 = cmplx(-1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c7f = "-1/2"
  complex(dp), parameter :: c8 = cmplx(-1d0/Nc, 0d0, kind=dp)
  character(len=20), parameter :: c8f = "-1/Nc"
  complex(dp), dimension(1:8) :: colorcoeffs = (/c1, c2, c3, c4, c5, c6, c7, c8&
                                               /)
  character(len=20), dimension(1:8) :: colorcoeffs_form = (/c1f, c2f, c3f, c4f &
                 , c5f, c6f, c7f, c8f/)
  integer, dimension(1:70) :: lorentz_rank = (/0, 0, 0, 1, 1, 0, 0, -1, 0, 1, 0&
                                             , 0, 0, 0, -1, -1, 0, 0, 1, -1, 1 &
                                             , 1, 1, 0, 1, 1, 1, 0, 1, 1, 1, -1&
                                             , -1, -1, 0, 0, 0, 0, 0, 0, 0, -1 &
                                             , 1, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1 &
                                             , 1, -1, -1, 1, 0, -1, 0, 1, -1, 0&
                                             , 1, 0, 0, 1, 1, 0, 1/)
  integer, dimension(1:70) :: recola_base = (/0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, &
                                            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                            , 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, &
                                            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                            , 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, &
                                            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                            , 0/)
  integer, dimension(1:70) :: propagator_extension = (/0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0/)
  character(len=*), parameter :: model_timestamp = "Mon Nov 12 12:51:01 2018"

  contains
    function get_timestamp_mdl() result(ret_timestamp)
      character(len=len(model_timestamp)) :: ret_timestamp
      ret_timestamp = model_timestamp
    end function get_timestamp_mdl

    function get_lorentz_rank_mdl(l_id) result(ret_lorentz_rank)
      integer, intent(in) :: l_id
      integer :: ret_lorentz_rank
      ret_lorentz_rank = lorentz_rank(l_id)
    end function get_lorentz_rank_mdl

    function get_propagator_extension_mdl(l_id) result(ret_pext)
      integer, intent(in) :: l_id
      integer :: ret_pext
      ret_pext = propagator_extension(l_id)
    end function get_propagator_extension_mdl

    function get_max_leg_multiplicity_mdl() result(ret_max_leg_multiplicity)
      integer :: ret_max_leg_multiplicity
      ret_max_leg_multiplicity = max_leg_multiplicity
    end function get_max_leg_multiplicity_mdl

    function is_model_init_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_init
    end function is_model_init_mdl

    function is_model_filled_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_filled
    end function is_model_filled_mdl

    subroutine get_vertex3_mdl(p1, p2, p3, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertex3_mdl

    subroutine get_vertex4_mdl(p1, p2, p3, p4, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3, p4
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, p4, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if
    end subroutine get_vertex4_mdl

    subroutine get_vertexN_mdl(particles, particleOut, vertex_ret)
      integer, intent(out)              :: vertex_ret
      integer, dimension(:), intent(in) :: particles
      integer, intent(in)               :: particleOut
      integer(kind=8)                   :: config
      integer                           :: address
      logical                           :: found_vertex

      call createParticleConfig(particles, particleOut, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertexN_mdl

    subroutine av(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branch(bid)%color_id = cid
      vertices(vid)%branch(bid)%colorfac_id = cfid
      vertices(vid)%branch(bid)%pext = pext
      vertices(vid)%branch(bid)%lorentz_id = lid
      vertices(vid)%branch(bid)%perm = perm
      vertices(vid)%branch(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branch(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branch(bid)%couplings(i) = cop(i)
      end do
    end subroutine av

    subroutine avCT(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchCT(bid)%color_id = cid
      vertices(vid)%branchCT(bid)%colorfac_id = cfid
      vertices(vid)%branchCT(bid)%pext = pext
      vertices(vid)%branchCT(bid)%lorentz_id = lid
      vertices(vid)%branchCT(bid)%perm = perm
      vertices(vid)%branchCT(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchCT(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchCT(bid)%couplings(i) = cop(i)
      end do
    end subroutine avCT

    subroutine avR2(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchR2(bid)%color_id = cid
      vertices(vid)%branchR2(bid)%colorfac_id = cfid
      vertices(vid)%branchR2(bid)%pext = pext
      vertices(vid)%branchR2(bid)%lorentz_id = lid
      vertices(vid)%branchR2(bid)%perm = perm
      vertices(vid)%branchR2(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchR2(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchR2(bid)%couplings(i) = cop(i)
      end do
    end subroutine avR2

    function get_colourfac_mdl(cfid)
      integer, intent(in) :: cfid
      complex(dp) :: get_colourfac_mdl
      get_colourfac_mdl = colorcoeffs(cfid)
    end function get_colourfac_mdl

    function get_colourfac_form_mdl(cfid)
      integer, intent(in) :: cfid
      character(len=20) :: get_colourfac_form_mdl
      get_colourfac_form_mdl = colorcoeffs_form(cfid)
    end function get_colourfac_form_mdl

  function get_recola_base_mdl(l_id) result(ret_rb)
      integer, intent(in) :: l_id
      integer :: ret_rb
      ret_rb = recola_base(l_id)
    end function get_recola_base_mdl

  subroutine get_vertex_branch_status_mdl(vx,xlp,branch_exists)
    integer, intent(in)  :: vx,xlp
    logical, intent(out) ::branch_exists
    select case (xlp)
    case(TreeBranch:LoopBranch)
      branch_exists = allocated(vertices(vx)%branch)
    case(CTBranch)
      branch_exists = allocated(vertices(vx)%branchCT)
    case(R2Branch)
      branch_exists = allocated(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_branch_status_mdl

  subroutine get_vertex_colour_branches_mdl(vx,xlp,cfids,nbranches)
    integer, allocatable, intent(out) :: cfids(:)
    integer, intent(out) :: nbranches
    integer, intent(in)  :: vx,xlp
    select case (xlp)
    case (TreeBranch:LoopBranch)
      allocate(cfids(size(vertices(vx)%branch)))
      cfids(:) = vertices(vx)%branch(0:)%color_id
      nbranches = size(vertices(vx)%branch)
    case(CTBranch)
      allocate(cfids(size(vertices(vx)%branchCT)))
      cfids(:) = vertices(vx)%branchCT(0:)%color_id
      nbranches = size(vertices(vx)%branchCT)
    case(R2Branch)
      allocate(cfids(size(vertices(vx)%branchR2)))
      cfids(:) = vertices(vx)%branchR2(0:)%color_id
      nbranches = size(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_colour_branches_mdl

  subroutine get_vertex_pext_mdl(vx,xlp,br,pext)
    integer, intent(in) :: vx,xlp,br
    integer, intent(out) :: pext
    select case (xlp)
    case (TreeBranch:LoopBranch)
      pext = vertices(vx)%branch(br)%pext
    case(CTBranch)
      pext = vertices(vx)%branchCT(br)%pext
    case(R2Branch)
      pext = vertices(vx)%branchR2(br)%pext
    end select
  end subroutine get_vertex_pext_mdl

  subroutine get_vertex_order_increase_mdl(vx,xlp,br,orderInc)
    integer, intent(in) :: vx,xlp,br
    integer, dimension(:), intent(out) :: orderInc
    select case (xlp)
    case (TreeBranch:LoopBranch)
      orderInc = vertices(vx)%branch(br)%coupling_order
    case(CTBranch)
      orderInc = vertices(vx)%branchCT(br)%coupling_order
    case(R2Branch)
      orderInc = vertices(vx)%branchR2(br)%coupling_order
    end select
  end subroutine get_vertex_order_increase_mdl

  subroutine get_vertex_lorentz_type_mdl(vx,xlp,br,lid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: lid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      lid = vertices(vx)%branch(br)%lorentz_id
    case(CTBranch)
      lid = vertices(vx)%branchCT(br)%lorentz_id
    case(R2Branch)
      lid = vertices(vx)%branchR2(br)%lorentz_id
    end select
  end subroutine get_vertex_lorentz_type_mdl

  subroutine get_vertex_perm_mdl(vx,xlp,br,perm)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: perm
    select case (xlp)
    case (TreeBranch:LoopBranch)
      perm = vertices(vx)%branch(br)%perm
    case(CTBranch)
      perm = vertices(vx)%branchCT(br)%perm
    case(R2Branch)
      perm = vertices(vx)%branchR2(br)%perm
    end select
  end subroutine get_vertex_perm_mdl

  subroutine get_vertex_colour_id_mdl(vx,xlp,br,cid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      cid = vertices(vx)%branch(br)%colorfac_id
    case(CTBranch)
      cid = vertices(vx)%branchCT(br)%colorfac_id
    case(R2Branch)
      cid = vertices(vx)%branchR2(br)%colorfac_id
    end select
  end subroutine get_vertex_colour_id_mdl

  function is_zero_coupling_vertex_mdl(vx,xlp,br) result(zero)
    use class_couplings, only: get_coupling_value_mdl
    use input_mdl, only: zerocut
    integer, intent(in)  :: vx,xlp,br
    logical              :: zero
    real(dp)             :: maxvalue
    integer              :: i

    zero = .false.
    select case (xlp)
    case (TreeBranch:LoopBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branch(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branch(br)%couplings(i-&
                1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(CTBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchCT(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchCT(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(R2Branch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchR2(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchR2(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    end select
  end function is_zero_coupling_vertex_mdl

  subroutine get_vertex_ncouplings_mdl(vx,xlp,br,ncouplings)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: ncouplings
    select case(xlp)
    case(TreeBranch, LoopBranch)
      ncouplings = size(vertices(vx)%branch(br)%couplings)
    case (CTBranch)
      ncouplings = size(vertices(vx)%branchCT(br)%couplings)
    case (R2Branch)
      ncouplings = size(vertices(vx)%branchR2(br)%couplings)
    end select
  end subroutine get_vertex_ncouplings_mdl

  subroutine get_vertex_coupling_ids_mdl(vx,xlp,br,cids)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cids(:)
    select case(xlp)
    case(TreeBranch, LoopBranch)
      cids(:) = vertices(vx)%branch(br)%couplings(:)
    case (CTBranch)
      cids(:) = vertices(vx)%branchCT(br)%couplings(:)
    case (R2Branch)
      cids(:) = vertices(vx)%branchR2(br)%couplings(:)
    end select
  end subroutine get_vertex_coupling_ids_mdl

    subroutine createCurrent2(P1, P2, id, check)
      integer, intent(in) :: P1, P2, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent2

    subroutine createCurrent3(P1, P2, P3, id, check)
      integer, intent(in) :: P1, P2, P3, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent3

    subroutine createCurrent4(P1, P2, P3, P4, id, check)
      integer, intent(in) :: P1, P2, P3, P4, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent4

    subroutine createCurrent5(P1, P2, P3, P4, P5, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent5

    subroutine createCurrent6(P1, P2, P3, P4, P5, P6, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent6

    subroutine createCurrent7(P1, P2, P3, P4, P5, P6, P7, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent7

    subroutine createCurrent8(P1, P2, P3, P4, P5, P6, P7, P8, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, P8, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, P8, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent8

    subroutine init_vertices_mdl()
      use constants_mdl
      use input_mdl, only: nx, error_mdl

      ! check if modelfile is compatible to drivers
      if (model_timestamp .ne. driver_timestamp) then
        call error_mdl("Model corrupted. Driver timestamp mismatch.", &
                      where='init_vertices')
      end if

      vertices_init = .true.
      call fill_couplings_mdl
      call init_CTparameters_mdl(.true.)
      call fill_CTcouplings_mdl
      call dict_init(3361)
      call createCurrents(.false.)

    end subroutine init_vertices_mdl

    subroutine createCurrents(check)
      logical, intent(in) :: check
      call createCurrent(P_GMinus, P_G0, P_A, P_WPlus, 27, check)
      call createCurrent(P_WPlus, P_GPlus, P_GMinus, P_WMinus, 1273, check)
      call createCurrent(P_GPlus, P_b, P_tAnti, 930, check)
      call createCurrent(P_b, P_bAnti, P_g, 256, check)
      call createCurrent(P_muPlus, P_Zp, P_tauMinus, 1164, check)
      call createCurrent(P_GPlus, P_A, P_Z, P_GMinus, 491, check)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_G0, 1309, check)
      call createCurrent(P_WpPlus, P_tAnti, P_s, 1137, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_H, 61, check)
      call createCurrent(P_WpMinus, P_dAnti, P_t, 473, check)
      call createCurrent(P_Z, P_GPlus, P_H, P_WMinus, 494, check)
      call createCurrent(P_GPlus, P_uAnti, P_s, 1269, check)
      call createCurrent(P_H, P_WMinus, P_WPlus, 1411, check)
      call createCurrent(P_WpPlus, P_s, P_cAnti, 325, check)
      call createCurrent(P_G0, P_G0, P_G0, P_G0, 36, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, 869, check)
      call createCurrent(P_s, P_sAnti, P_H, 895, check)
      call createCurrent(P_cAnti, P_WpPlus, P_d, 83, check)
      call createCurrent(P_WpMinus, P_nu_e, P_ePlus, 678, check)
      call createCurrent(P_GPlus, P_A, P_G0, P_WMinus, 1318, check)
      call createCurrent(P_WMinus, P_G0, P_G0, P_WPlus, 33, check)
      call createCurrent(P_WPlus, P_g, P_WpMinus, P_g, 1592, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, 834, check)
      call createCurrent(P_Zp, P_s, P_sAnti, 6, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_A, 132, check)
      call createCurrent(P_u, P_cAnti, P_Zp, 1358, check)
      call createCurrent(P_c, P_GMinus, P_dAnti, 51, check)
      call createCurrent(P_bAnti, P_d, P_Zp, 1327, check)
      call createCurrent(P_A, P_ePlus, P_eMinus, 463, check)
      call createCurrent(P_s, P_WpPlus, P_cAnti, 1064, check)
      call createCurrent(P_nu_e, P_ePlus, P_WpMinus, 707, check)
      call createCurrent(P_ghWmAnti, P_H, P_ghWm, 227, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_A, 1396, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GPlus, 534, check)
      call createCurrent(P_tauMinus, P_WpPlus, P_nu_tauAnti, 685, check)
      call createCurrent(P_Z, P_tauPlus, P_tauMinus, 655, check)
      call createCurrent(P_WMinus, P_dAnti, P_u, 481, check)
      call createCurrent(P_WPlus, P_WMinus, P_H, P_H, 12, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, 720, check)
      call createCurrent(P_Z, P_WPlus, P_A, P_WMinus, 1326, check)
      call createCurrent(P_WPlus, P_Z, P_A, P_WMinus, 222, check)
      call createCurrent(P_G0, P_GPlus, P_Z, P_WMinus, 1213, check)
      call createCurrent(P_Z, P_WPlus, P_Z, P_WMinus, 302, check)
      call createCurrent(P_WMinus, P_H, P_Z, P_GPlus, 243, check)
      call createCurrent(P_ePlus, P_WpMinus, P_nu_e, 532, check)
      call createCurrent(P_Zp, P_d, P_bAnti, 994, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, 79, check)
      call createCurrent(P_bAnti, P_b, P_g, 524, check)
      call createCurrent(P_cAnti, P_Z, P_c, 175, check)
      call createCurrent(P_eMinus, P_WPlus, P_nu_eAnti, 543, check)
      call createCurrent(P_Zp, P_tauMinus, P_ePlus, 925, check)
      call createCurrent(P_GPlus, P_GMinus, P_WPlus, P_WMinus, 651, check)
      call createCurrent(P_Z, P_ePlus, P_eMinus, 1166, check)
      call createCurrent(P_A, P_tauPlus, P_tauMinus, 398, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_Z, 369, check)
      call createCurrent(P_t, P_Z, P_tAnti, 1080, check)
      call createCurrent(P_G0, P_dAnti, P_d, 37, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, 1100, check)
      call createCurrent(P_s, P_Z, P_sAnti, 1212, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_Z, 1279, check)
      call createCurrent(P_nu_e, P_WMinus, P_ePlus, 271, check)
      call createCurrent(P_H, P_cAnti, P_c, 185, check)
      call createCurrent(P_bAnti, P_b, P_Z, 1310, check)
      call createCurrent(P_H, P_H, P_GPlus, P_GMinus, 41, check)
      call createCurrent(P_GMinus, P_dAnti, P_u, 62, check)
      call createCurrent(P_H, P_sAnti, P_d, 139, check)
      call createCurrent(P_A, P_muPlus, P_muMinus, 0, check)
      call createCurrent(P_WMinus, P_GMinus, P_GPlus, P_WPlus, 14, check)
      call createCurrent(P_H, P_Z, P_GMinus, P_WPlus, 327, check)
      call createCurrent(P_G0, P_uAnti, P_u, 1291, check)
      call createCurrent(P_G0, P_c, P_cAnti, 301, check)
      call createCurrent(P_s, P_uAnti, P_GPlus, 70, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, 908, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_Z, 177, check)
      call createCurrent(P_g, P_H, P_H, P_g, 1608, check)
      call createCurrent(P_WpPlus, P_WMinus, P_g, P_g, 1656, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_G0, 898, check)
      call createCurrent(P_g, P_g, P_Z, P_Zp, 1567, check)
      call createCurrent(P_Zp, P_sAnti, P_b, 475, check)
      call createCurrent(P_uAnti, P_s, P_WpPlus, 1302, check)
      call createCurrent(P_sAnti, P_WpMinus, P_u, 1439, check)
      call createCurrent(P_WMinus, P_g, P_WPlus, P_g, 1585, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WPlus, 465, check)
      call createCurrent(P_tauMinus, P_Zp, P_muPlus, 161, check)
      call createCurrent(P_dAnti, P_t, P_WpMinus, 990, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_G0, 845, check)
      call createCurrent(P_sAnti, P_s, P_H, 1050, check)
      call createCurrent(P_A, P_H, P_GMinus, P_WPlus, 464, check)
      call createCurrent(P_dAnti, P_d, P_A, 428, check)
      call createCurrent(P_WpPlus, P_WpMinus, P_g, P_g, 1598, check)
      call createCurrent(P_Z, P_uAnti, P_u, 451, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_Z, 176, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_A, 1079, check)
      call createCurrent(P_Z, P_WMinus, P_G0, P_GPlus, 1496, check)
      call createCurrent(P_Zp, P_A, P_g, P_g, 1564, check)
      call createCurrent(P_GPlus, P_nu_muAnti, P_muMinus, 163, check)
      call createCurrent(P_GPlus, P_H, P_GMinus, P_H, 159, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, 705, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, 1330, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_A, 1428, check)
      call createCurrent(P_dAnti, P_g, P_d, 767, check)
      call createCurrent(P_WpMinus, P_muPlus, P_nu_e, 1424, check)
      call createCurrent(P_c, P_cAnti, P_A, 1354, check)
      call createCurrent(P_Zp, P_g, P_g, P_Z, 1595, check)
      call createCurrent(P_tauMinus, P_nu_muAnti, P_WpPlus, 589, check)
      call createCurrent(P_H, P_dAnti, P_s, 1071, check)
      call createCurrent(P_WPlus, P_g, P_WMinus, P_g, 1602, check)
      call createCurrent(P_cAnti, P_GPlus, P_d, 1003, check)
      call createCurrent(P_G0, P_sAnti, P_d, 1090, check)
      call createCurrent(P_tAnti, P_t, P_A, 1471, check)
      call createCurrent(P_tauMinus, P_tauPlus, 1519, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, 357, check)
      call createCurrent(P_b, P_WpPlus, P_cAnti, 1248, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_H, 344, check)
      call createCurrent(P_eMinus, P_muPlus, P_Zp, 283, check)
      call createCurrent(P_c, P_sAnti, P_WMinus, 467, check)
      call createCurrent(P_c, P_WpMinus, P_dAnti, 497, check)
      call createCurrent(P_A, P_d, P_dAnti, 899, check)
      call createCurrent(P_dAnti, P_c, P_WMinus, 1285, check)
      call createCurrent(P_H, P_WPlus, P_WMinus, 232, check)
      call createCurrent(P_GPlus, P_tauMinus, P_nu_tauAnti, 1133, check)
      call createCurrent(P_H, P_H, P_H, 986, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, 1427, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WMinus, 564, check)
      call createCurrent(P_d, P_WpPlus, P_tAnti, 675, check)
      call createCurrent(P_g, P_WpMinus, P_g, P_WpPlus, 1660, check)
      call createCurrent(P_muMinus, P_Zp, P_tauPlus, 1449, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_A, 1062, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_A, 1478, check)
      call createCurrent(P_uAnti, P_u, 1522, check)
      call createCurrent(P_WpMinus, P_bAnti, P_c, 169, check)
      call createCurrent(P_Zp, P_bAnti, P_d, 262, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_Z, 380, check)
      call createCurrent(P_sAnti, P_A, P_s, 548, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, P_Z, 153, check)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_GMinus, 885, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WpPlus, 76, check)
      call createCurrent(P_nu_muAnti, P_WpPlus, P_muMinus, 1407, check)
      call createCurrent(P_eMinus, P_ePlus, P_Zp, 1418, check)
      call createCurrent(P_uAnti, P_WPlus, P_s, 508, check)
      call createCurrent(P_tauPlus, P_Zp, P_tauMinus, 216, check)
      call createCurrent(P_d, P_H, P_sAnti, 1289, check)
      call createCurrent(P_t, P_sAnti, P_WpMinus, 28, check)
      call createCurrent(P_uAnti, P_WpPlus, P_s, 350, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, 422, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_G0, 1023, check)
      call createCurrent(P_uAnti, P_u, P_g, 1018, check)
      call createCurrent(P_nu_e, P_WpMinus, P_muPlus, 111, check)
      call createCurrent(P_WpPlus, P_s, P_tAnti, 1167, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, 1190, check)
      call createCurrent(P_nu_eAnti, P_muMinus, P_WpPlus, 496, check)
      call createCurrent(P_GMinus, P_H, P_A, P_WPlus, 441, check)
      call createCurrent(P_u, P_uAnti, 1527, check)
      call createCurrent(P_WpPlus, P_g, P_WpMinus, P_g, 1626, check)
      call createCurrent(P_cAnti, P_c, P_Zp, 806, check)
      call createCurrent(P_sAnti, P_H, P_s, 102, check)
      call createCurrent(P_s, P_WpPlus, P_uAnti, 143, check)
      call createCurrent(P_tAnti, P_t, P_Z, 166, check)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_GPlus, 1065, check)
      call createCurrent(P_s, P_sAnti, P_Zp, 1028, check)
      call createCurrent(P_cAnti, P_d, P_GPlus, 836, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, 218, check)
      call createCurrent(P_g, P_WPlus, P_WpMinus, P_g, 1597, check)
      call createCurrent(P_sAnti, P_b, P_Zp, 525, check)
      call createCurrent(P_d, P_cAnti, P_GPlus, 162, check)
      call createCurrent(P_G0, P_H, P_G0, 512, check)
      call createCurrent(P_WMinus, P_dAnti, P_c, 1092, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_G0, 431, check)
      call createCurrent(P_A, P_H, P_WMinus, P_GPlus, 1070, check)
      call createCurrent(P_G0, P_Z, P_WPlus, P_GMinus, 279, check)
      call createCurrent(P_s, P_H, P_sAnti, 517, check)
      call createCurrent(P_cAnti, P_c, 1532, check)
      call createCurrent(P_uAnti, P_u, P_Zp, 373, check)
      call createCurrent(P_cAnti, P_Zp, P_t, 1423, check)
      call createCurrent(P_c, P_cAnti, P_G0, 489, check)
      call createCurrent(P_WpPlus, P_cAnti, P_b, 1380, check)
      call createCurrent(P_GPlus, P_eMinus, P_nu_eAnti, 196, check)
      call createCurrent(P_tauMinus, P_Zp, P_ePlus, 462, check)
      call createCurrent(P_c, P_sAnti, P_WpMinus, 1250, check)
      call createCurrent(P_WMinus, P_H, P_WPlus, 354, check)
      call createCurrent(P_G0, P_tAnti, P_t, 425, check)
      call createCurrent(P_dAnti, P_Zp, P_b, 208, check)
      call createCurrent(P_Z, P_G0, P_Z, P_G0, 745, check)
      call createCurrent(P_bAnti, P_Zp, P_d, 1136, check)
      call createCurrent(P_s, P_dAnti, P_G0, 814, check)
      call createCurrent(P_tauPlus, P_WpMinus, P_nu_e, 1277, check)
      call createCurrent(P_s, P_GPlus, P_cAnti, 1201, check)
      call createCurrent(P_WMinus, P_H, P_WPlus, P_H, 713, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, 461, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, 1265, check)
      call createCurrent(P_dAnti, P_d, P_g, 310, check)
      call createCurrent(P_WMinus, P_G0, P_A, P_GPlus, 950, check)
      call createCurrent(P_c, P_cAnti, 1517, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_A, 914, check)
      call createCurrent(P_WpMinus, P_c, P_bAnti, 1076, check)
      call createCurrent(P_tauMinus, P_Zp, P_tauPlus, 1393, check)
      call createCurrent(P_GPlus, P_s, P_cAnti, 1287, check)
      call createCurrent(P_s, P_Zp, P_sAnti, 1054, check)
      call createCurrent(P_A, P_H, P_GPlus, P_WMinus, 821, check)
      call createCurrent(P_muPlus, P_muMinus, P_A, 316, check)
      call createCurrent(P_eMinus, P_nu_tauAnti, P_WpPlus, 521, check)
      call createCurrent(P_s, P_sAnti, P_g, 536, check)
      call createCurrent(P_uAnti, P_Z, P_u, 300, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, 948, check)
      call createCurrent(P_ePlus, P_nu_e, P_WpMinus, 1061, check)
      call createCurrent(P_A, P_GPlus, P_H, P_WMinus, 1268, check)
      call createCurrent(P_d, P_dAnti, 1506, check)
      call createCurrent(P_H, P_A, P_WMinus, P_GPlus, 1372, check)
      call createCurrent(P_A, P_Zp, P_g, P_g, 1571, check)
      call createCurrent(P_nu_e, P_ePlus, P_WMinus, 1404, check)
      call createCurrent(P_H, P_G0, P_Z, 1034, check)
      call createCurrent(P_d, P_GPlus, P_cAnti, 693, check)
      call createCurrent(P_uAnti, P_d, P_WpPlus, 1030, check)
      call createCurrent(P_H, P_s, P_dAnti, 43, check)
      call createCurrent(P_d, P_Zp, P_bAnti, 847, check)
      call createCurrent(P_Z, P_g, P_g, P_Zp, 1612, check)
      call createCurrent(P_g, P_WpPlus, P_g, P_WpMinus, 1562, check)
      call createCurrent(P_WpMinus, P_nu_tau, P_tauPlus, 866, check)
      call createCurrent(P_d, P_sAnti, P_H, 1337, check)
      call createCurrent(P_G0, P_d, P_dAnti, 1073, check)
      call createCurrent(P_bAnti, P_G0, P_b, 115, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_G0, 142, check)
      call createCurrent(P_H, P_Z, P_G0, 220, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_H, 237, check)
      call createCurrent(P_WpPlus, P_nu_muAnti, P_eMinus, 1266, check)
      call createCurrent(P_bAnti, P_Z, P_b, 1170, check)
      call createCurrent(P_G0, P_tauPlus, P_tauMinus, 1120, check)
      call createCurrent(P_G0, P_g, P_G0, P_g, 1555, check)
      call createCurrent(P_d, P_dAnti, P_A, 886, check)
      call createCurrent(P_Z, P_GPlus, P_Z, P_GMinus, 614, check)
      call createCurrent(P_s, P_GPlus, P_uAnti, 1058, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WpMinus, 1278, check)
      call createCurrent(P_u, P_Zp, P_tAnti, 841, check)
      call createCurrent(P_H, P_muPlus, P_muMinus, 842, check)
      call createCurrent(P_WPlus, P_WMinus, 1516, check)
      call createCurrent(P_G0, P_Z, P_WMinus, P_GPlus, 954, check)
      call createCurrent(P_Z, P_nu_tauAnti, P_nu_tau, 664, check)
      call createCurrent(P_dAnti, P_WpMinus, P_u, 887, check)
      call createCurrent(P_muMinus, P_muPlus, P_Zp, 605, check)
      call createCurrent(P_A, P_g, P_Zp, P_g, 1587, check)
      call createCurrent(P_u, P_Zp, P_cAnti, 1029, check)
      call createCurrent(P_c, P_dAnti, P_GMinus, 326, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_H, 979, check)
      call createCurrent(P_A, P_A, P_GMinus, P_GPlus, 1068, check)
      call createCurrent(P_tauMinus, P_WpPlus, P_nu_eAnti, 722, check)
      call createCurrent(P_muPlus, P_A, P_muMinus, 1157, check)
      call createCurrent(P_WMinus, P_A, P_G0, P_GPlus, 1208, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_A, 1220, check)
      call createCurrent(P_GPlus, P_A, P_A, P_GMinus, 1259, check)
      call createCurrent(P_eMinus, P_GPlus, P_nu_eAnti, 370, check)
      call createCurrent(P_Zp, P_g, P_g, P_g, 1677, check)
      call createCurrent(P_H, P_GPlus, P_GMinus, P_H, 1413, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, 748, check)
      call createCurrent(P_d, P_G0, P_dAnti, 1130, check)
      call createCurrent(P_s, P_WPlus, P_cAnti, 920, check)
      call createCurrent(P_dAnti, P_WMinus, P_u, 189, check)
      call createCurrent(P_g, P_WMinus, P_g, P_WPlus, 1570, check)
      call createCurrent(P_WpPlus, P_uAnti, P_d, 242, check)
      call createCurrent(P_Zp, P_tAnti, P_u, 1026, check)
      call createCurrent(P_tAnti, P_Zp, P_t, 1472, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, 773, check)
      call createCurrent(P_G0, P_GMinus, P_Z, P_WPlus, 445, check)
      call createCurrent(P_d, P_cAnti, P_WPlus, 30, check)
      call createCurrent(P_g, P_g, P_WpPlus, P_WMinus, 1643, check)
      call createCurrent(P_muPlus, P_nu_tau, P_WpMinus, 82, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WpMinus, 1334, check)
      call createCurrent(P_g, P_g, P_A, P_Z, 1601, check)
      call createCurrent(P_GPlus, P_g, P_GMinus, P_g, 1569, check)
      call createCurrent(P_A, P_Z, P_WMinus, P_WPlus, 88, check)
      call createCurrent(P_muPlus, P_H, P_muMinus, 1200, check)
      call createCurrent(P_A, P_s, P_sAnti, 1454, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_Z, 770, check)
      call createCurrent(P_Zp, P_tauMinus, P_tauPlus, 909, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, 92, check)
      call createCurrent(P_H, P_d, P_sAnti, 731, check)
      call createCurrent(P_A, P_WMinus, P_Z, P_WPlus, 740, check)
      call createCurrent(P_A, P_H, P_WPlus, P_GMinus, 190, check)
      call createCurrent(P_d, P_g, P_dAnti, 1069, check)
      call createCurrent(P_g, P_t, P_tAnti, 961, check)
      call createCurrent(P_G0, P_Z, P_G0, P_Z, 1135, check)
      call createCurrent(P_t, P_tAnti, 1523, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, 276, check)
      call createCurrent(P_sAnti, P_WMinus, P_u, 545, check)
      call createCurrent(P_b, P_bAnti, P_Zp, 1371, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, 1514, check)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_GPlus, 971, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, 1129, check)
      call createCurrent(P_c, P_cAnti, P_g, 192, check)
      call createCurrent(P_A, P_G0, P_WPlus, P_GMinus, 556, check)
      call createCurrent(P_c, P_cAnti, P_Zp, 585, check)
      call createCurrent(P_u, P_uAnti, P_Z, 284, check)
      call createCurrent(P_GPlus, P_H, P_Z, P_WMinus, 1115, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_Z, 788, check)
      call createCurrent(P_t, P_bAnti, P_WMinus, 285, check)
      call createCurrent(P_ghWpAnti, P_H, P_ghWp, 306, check)
      call createCurrent(P_uAnti, P_WpPlus, P_d, 1126, check)
      call createCurrent(P_g, P_b, P_bAnti, 1229, check)
      call createCurrent(P_A, P_b, P_bAnti, 1146, check)
      call createCurrent(P_g, P_g, P_H, P_H, 1620, check)
      call createCurrent(P_ePlus, P_eMinus, P_G0, 87, check)
      call createCurrent(P_c, P_H, P_cAnti, 1159, check)
      call createCurrent(P_A, P_Z, P_WPlus, P_WMinus, 435, check)
      call createCurrent(P_GMinus, P_nu_tau, P_tauPlus, 120, check)
      call createCurrent(P_tAnti, P_Zp, P_c, 661, check)
      call createCurrent(P_A, P_WPlus, P_G0, P_GMinus, 741, check)
      call createCurrent(P_GMinus, P_u, P_sAnti, 1206, check)
      call createCurrent(P_uAnti, P_Zp, P_t, 215, check)
      call createCurrent(P_ePlus, P_eMinus, P_H, 203, check)
      call createCurrent(P_g, P_Zp, P_g, 1623, check)
      call createCurrent(P_WPlus, P_WMinus, P_WMinus, P_WPlus, 343, check)
      call createCurrent(P_d, P_H, P_dAnti, 11, check)
      call createCurrent(P_g, P_GPlus, P_GMinus, P_g, 1681, check)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_GMinus, 1375, check)
      call createCurrent(P_sAnti, P_s, P_G0, 617, check)
      call createCurrent(P_WpMinus, P_sAnti, P_t, 423, check)
      call createCurrent(P_u, P_G0, P_uAnti, 772, check)
      call createCurrent(P_H, P_A, P_GMinus, P_WPlus, 942, check)
      call createCurrent(P_Zp, P_uAnti, P_u, 727, check)
      call createCurrent(P_WpPlus, P_tauMinus, P_nu_tauAnti, 1270, check)
      call createCurrent(P_G0, P_cAnti, P_c, 964, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_H, 1313, check)
      call createCurrent(P_G0, P_sAnti, P_s, 322, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, 924, check)
      call createCurrent(P_H, P_t, P_tAnti, 1357, check)
      call createCurrent(P_muPlus, P_WpMinus, P_nu_tau, 224, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, 674, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, 1349, check)
      call createCurrent(P_eMinus, P_ePlus, P_A, 637, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_H, 837, check)
      call createCurrent(P_WpMinus, P_ePlus, P_nu_tau, 944, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_G0, 504, check)
      call createCurrent(P_GPlus, P_GMinus, P_g, P_g, 1652, check)
      call createCurrent(P_Zp, P_sAnti, P_s, 296, check)
      call createCurrent(P_Zp, P_t, P_uAnti, 436, check)
      call createCurrent(P_d, P_GPlus, P_uAnti, 1464, check)
      call createCurrent(P_H, P_Z, P_WMinus, P_GPlus, 352, check)
      call createCurrent(P_Z, P_GMinus, P_Z, P_GPlus, 255, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, 13, check)
      call createCurrent(P_WMinus, P_Z, P_H, P_GPlus, 330, check)
      call createCurrent(P_c, P_dAnti, P_WpMinus, 1158, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, 1457, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_H, 711, check)
      call createCurrent(P_WMinus, P_WPlus, P_WMinus, P_WPlus, 1292, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_Z, 1196, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, 1402, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, 1225, check)
      call createCurrent(P_Z, P_eMinus, P_ePlus, 1323, check)
      call createCurrent(P_g, P_g, P_g, P_Z, 1548, check)
      call createCurrent(P_muPlus, P_Zp, P_eMinus, 1207, check)
      call createCurrent(P_bAnti, P_WMinus, P_t, 476, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_Z, 804, check)
      call createCurrent(P_WpMinus, P_dAnti, P_c, 1255, check)
      call createCurrent(P_Z, P_WPlus, P_G0, P_GMinus, 853, check)
      call createCurrent(P_muPlus, P_GMinus, P_nu_mu, 318, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_H, 195, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, 1221, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WpMinus, 493, check)
      call createCurrent(P_d, P_WpPlus, P_cAnti, 659, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_G0, 340, check)
      call createCurrent(P_H, P_u, P_uAnti, 852, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, 259, check)
      call createCurrent(P_GMinus, P_A, P_G0, P_WPlus, 1099, check)
      call createCurrent(P_tauPlus, P_tauMinus, 1536, check)
      call createCurrent(P_c, P_Z, P_cAnti, 735, check)
      call createCurrent(P_g, P_H, P_g, P_H, 1633, check)
      call createCurrent(P_H, P_b, P_bAnti, 947, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_Z, 1237, check)
      call createCurrent(P_WpMinus, P_g, P_WPlus, P_g, 1613, check)
      call createCurrent(P_WMinus, P_u, P_sAnti, 440, check)
      call createCurrent(P_g, P_g, 1503, check)
      call createCurrent(P_Z, P_Z, P_H, 315, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, 572, check)
      call createCurrent(P_GPlus, P_WPlus, P_GMinus, P_WMinus, 1153, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, 802, check)
      call createCurrent(P_WMinus, P_H, P_H, P_WPlus, 1168, check)
      call createCurrent(P_WPlus, P_nu_eAnti, P_eMinus, 891, check)
      call createCurrent(P_WPlus, P_A, P_G0, P_GMinus, 892, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_Z, 702, check)
      call createCurrent(P_A, P_WMinus, P_H, P_GPlus, 832, check)
      call createCurrent(P_Zp, P_muMinus, P_ePlus, 786, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, 730, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_A, 978, check)
      call createCurrent(P_Zp, P_muPlus, P_muMinus, 272, check)
      call createCurrent(P_u, P_uAnti, P_g, 1324, check)
      call createCurrent(P_g, P_g, P_Z, P_Z, 1559, check)
      call createCurrent(P_nu_tauAnti, P_eMinus, P_WpPlus, 171, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, 1218, check)
      call createCurrent(P_GPlus, P_H, P_A, P_WMinus, 684, check)
      call createCurrent(P_Zp, P_cAnti, P_t, 551, check)
      call createCurrent(P_ePlus, P_nu_e, P_GMinus, 1257, check)
      call createCurrent(P_tauPlus, P_H, P_tauMinus, 1132, check)
      call createCurrent(P_A, P_G0, P_WMinus, P_GPlus, 1430, check)
      call createCurrent(P_g, P_g, P_Zp, P_Z, 1645, check)
      call createCurrent(P_Z, P_A, P_GPlus, P_GMinus, 571, check)
      call createCurrent(P_u, P_g, P_uAnti, 992, check)
      call createCurrent(P_GPlus, P_G0, P_Z, P_WMinus, 235, check)
      call createCurrent(P_tAnti, P_u, P_Zp, 765, check)
      call createCurrent(P_dAnti, P_c, P_GMinus, 456, check)
      call createCurrent(P_H, P_WPlus, P_GMinus, 391, check)
      call createCurrent(P_muMinus, P_WpPlus, P_nu_muAnti, 145, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_H, 48, check)
      call createCurrent(P_s, P_tAnti, P_WpPlus, 676, check)
      call createCurrent(P_nu_tauAnti, P_GPlus, P_tauMinus, 8, check)
      call createCurrent(P_A, P_WPlus, P_Z, P_WMinus, 526, check)
      call createCurrent(P_ePlus, P_eMinus, P_A, 760, check)
      call createCurrent(P_Zp, P_bAnti, P_s, 1067, check)
      call createCurrent(P_GPlus, P_g, P_g, P_GMinus, 1550, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_Z, 1469, check)
      call createCurrent(P_WpPlus, P_tauMinus, P_nu_eAnti, 1044, check)
      call createCurrent(P_ghZAnti, P_H, P_ghZ, 1232, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_H, 716, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, 1191, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GPlus, 412, check)
      call createCurrent(P_H, P_Z, P_Z, P_H, 778, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, 995, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, 167, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_Z, 21, check)
      call createCurrent(P_nu_tau, P_WpMinus, P_tauPlus, 1182, check)
      call createCurrent(P_d, P_G0, P_sAnti, 1171, check)
      call createCurrent(P_t, P_tAnti, P_A, 261, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_H, 170, check)
      call createCurrent(P_H, P_ghWpAnti, P_ghWp, 1101, check)
      call createCurrent(P_H, P_tauPlus, P_tauMinus, 1298, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_G0, 568, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_A, 505, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_A, 513, check)
      call createCurrent(P_g, P_Z, P_g, P_Z, 1568, check)
      call createCurrent(P_GPlus, P_Z, P_Z, P_GMinus, 870, check)
      call createCurrent(P_t, P_tAnti, P_G0, 333, check)
      call createCurrent(P_dAnti, P_WpMinus, P_t, 1331, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, 1121, check)
      call createCurrent(P_d, P_WPlus, P_uAnti, 1138, check)
      call createCurrent(P_dAnti, P_u, P_GMinus, 1301, check)
      call createCurrent(P_Zp, P_muMinus, P_muPlus, 63, check)
      call createCurrent(P_g, P_Zp, P_g, P_Z, 1575, check)
      call createCurrent(P_cAnti, P_s, P_WpPlus, 2, check)
      call createCurrent(P_nu_mu, P_ePlus, P_WpMinus, 448, check)
      call createCurrent(P_GPlus, P_G0, P_A, P_WMinus, 289, check)
      call createCurrent(P_G0, P_WMinus, P_G0, P_WPlus, 266, check)
      call createCurrent(P_WMinus, P_nu_mu, P_muPlus, 1316, check)
      call createCurrent(P_GPlus, P_cAnti, P_d, 247, check)
      call createCurrent(P_WPlus, P_Z, P_G0, P_GMinus, 93, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, 817, check)
      call createCurrent(P_H, P_ghZAnti, P_ghZ, 771, check)
      call createCurrent(P_G0, P_eMinus, P_ePlus, 164, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_Z, 47, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, 98, check)
      call createCurrent(P_ePlus, P_Zp, P_tauMinus, 1465, check)
      call createCurrent(P_u, P_dAnti, P_WMinus, 830, check)
      call createCurrent(P_tAnti, P_GPlus, P_b, 683, check)
      call createCurrent(P_Z, P_Z, P_g, P_g, 1583, check)
      call createCurrent(P_s, P_A, P_sAnti, 1009, check)
      call createCurrent(P_s, P_WpPlus, P_tAnti, 107, check)
      call createCurrent(P_G0, P_WMinus, P_Z, P_GPlus, 877, check)
      call createCurrent(P_muPlus, P_muMinus, P_G0, 85, check)
      call createCurrent(P_nu_muAnti, P_WpPlus, P_eMinus, 798, check)
      call createCurrent(P_G0, P_H, P_Z, 531, check)
      call createCurrent(P_d, P_cAnti, P_WpPlus, 795, check)
      call createCurrent(P_H, P_H, P_WMinus, P_WPlus, 759, check)
      call createCurrent(P_GMinus, P_dAnti, P_c, 854, check)
      call createCurrent(P_GMinus, P_bAnti, P_t, 225, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_Z, 929, check)
      call createCurrent(P_G0, P_g, P_g, P_G0, 1639, check)
      call createCurrent(P_cAnti, P_A, P_c, 1383, check)
      call createCurrent(P_g, P_g, P_H, 1629, check)
      call createCurrent(P_muPlus, P_muMinus, P_H, 896, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_Z, 1391, check)
      call createCurrent(P_tauPlus, P_G0, P_tauMinus, 557, check)
      call createCurrent(P_tauMinus, P_WPlus, P_nu_tauAnti, 1398, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_G0, 1086, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, 468, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_Z, 1239, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_H, 1088, check)
      call createCurrent(P_muMinus, P_muPlus, 1501, check)
      call createCurrent(P_uAnti, P_Zp, P_c, 970, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_A, 1096, check)
      call createCurrent(P_bAnti, P_b, P_G0, 1021, check)
      call createCurrent(P_g, P_g, P_WpPlus, P_WpMinus, 1636, check)
      call createCurrent(P_g, P_GMinus, P_GPlus, P_g, 1646, check)
      call createCurrent(P_Z, P_nu_tau, P_nu_tauAnti, 372, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, 1440, check)
      call createCurrent(P_WPlus, P_nu_muAnti, P_muMinus, 424, check)
      call createCurrent(P_muMinus, P_muPlus, P_A, 174, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_G0, 578, check)
      call createCurrent(P_WMinus, P_c, P_sAnti, 826, check)
      call createCurrent(P_sAnti, P_u, P_GMinus, 1103, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_A, 165, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_G0, 1165, check)
      call createCurrent(P_G0, P_A, P_WMinus, P_GPlus, 71, check)
      call createCurrent(P_b, P_bAnti, P_G0, 888, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, 131, check)
      call createCurrent(P_tauPlus, P_A, P_tauMinus, 152, check)
      call createCurrent(P_WPlus, P_Z, P_H, P_GMinus, 1057, check)
      call createCurrent(P_sAnti, P_t, P_WpMinus, 921, check)
      call createCurrent(P_H, P_sAnti, P_s, 1468, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_A, 1473, check)
      call createCurrent(P_WpMinus, P_sAnti, P_u, 379, check)
      call createCurrent(P_Zp, P_uAnti, P_c, 123, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_A, 1299, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, 724, check)
      call createCurrent(P_nu_tau, P_ePlus, P_WpMinus, 644, check)
      call createCurrent(P_WpMinus, P_nu_mu, P_tauPlus, 1254, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_H, 72, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, 1422, check)
      call createCurrent(P_s, P_cAnti, P_WPlus, 65, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_G0, 1052, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, 667, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, 968, check)
      call createCurrent(P_muPlus, P_WpMinus, P_nu_mu, 1467, check)
      call createCurrent(P_Z, P_Z, P_WPlus, P_WMinus, 848, check)
      call createCurrent(P_nu_eAnti, P_nu_e, 1513, check)
      call createCurrent(P_WPlus, P_b, P_tAnti, 630, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_A, 1022, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, 240, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, 154, check)
      call createCurrent(P_G0, P_Z, 1534, check)
      call createCurrent(P_WMinus, P_Z, P_A, P_WPlus, 78, check)
      call createCurrent(P_WPlus, P_WMinus, P_g, P_g, 1638, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, 1180, check)
      call createCurrent(P_Z, P_g, P_g, P_Z, 1661, check)
      call createCurrent(P_tAnti, P_c, P_Zp, 260, check)
      call createCurrent(P_WPlus, P_uAnti, P_s, 643, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_G0, 657, check)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_GMinus, 743, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, 963, check)
      call createCurrent(P_G0, P_bAnti, P_b, 1240, check)
      call createCurrent(P_uAnti, P_b, P_WpPlus, 348, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_A, 801, check)
      call createCurrent(P_sAnti, P_WpMinus, P_c, 229, check)
      call createCurrent(P_G0, P_ghWp, P_ghWpAnti, 386, check)
      call createCurrent(P_GMinus, P_tauPlus, P_nu_tau, 1431, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_Z, 1395, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WpPlus, 1476, check)
      call createCurrent(P_Zp, P_muPlus, P_eMinus, 982, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_G0, 324, check)
      call createCurrent(P_t, P_WpMinus, P_dAnti, 527, check)
      call createCurrent(P_A, P_GMinus, P_G0, P_WPlus, 1410, check)
      call createCurrent(P_uAnti, P_s, P_GPlus, 20, check)
      call createCurrent(P_WMinus, P_A, P_A, P_WPlus, 1217, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_A, 1226, check)
      call createCurrent(P_c, P_WpMinus, P_sAnti, 1455, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_H, 1406, check)
      call createCurrent(P_g, P_A, P_g, P_Z, 1557, check)
      call createCurrent(P_WPlus, P_tAnti, P_b, 980, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, 1505, check)
      call createCurrent(P_nu_eAnti, P_WPlus, P_eMinus, 612, check)
      call createCurrent(P_Z, P_WMinus, P_Z, P_WPlus, 733, check)
      call createCurrent(P_A, P_g, P_g, P_Z, 1553, check)
      call createCurrent(P_nu_eAnti, P_WpPlus, P_eMinus, 996, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_Z, 634, check)
      call createCurrent(P_g, P_g, P_Zp, P_A, 1545, check)
      call createCurrent(P_A, P_GPlus, P_Z, P_GMinus, 67, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, 583, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_A, 957, check)
      call createCurrent(P_Z, P_u, P_uAnti, 264, check)
      call createCurrent(P_H, P_g, P_g, P_H, 1649, check)
      call createCurrent(P_Zp, P_g, P_Zp, P_g, 1542, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, 157, check)
      call createCurrent(P_Z, P_nu_mu, P_nu_muAnti, 863, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_A, 1400, check)
      call createCurrent(P_u, P_sAnti, P_GMinus, 399, check)
      call createCurrent(P_WpPlus, P_nu_eAnti, P_tauMinus, 68, check)
      call createCurrent(P_WPlus, P_uAnti, P_d, 1038, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, 918, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, 35, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_Z, 923, check)
      call createCurrent(P_Z, P_g, P_g, P_A, 1582, check)
      call createCurrent(P_bAnti, P_t, P_WpMinus, 625, check)
      call createCurrent(P_H, P_GPlus, P_A, P_WMinus, 498, check)
      call createCurrent(P_uAnti, P_A, P_u, 1031, check)
      call createCurrent(P_g, P_g, P_Zp, P_Zp, 1611, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, 146, check)
      call createCurrent(P_Z, P_A, P_GMinus, P_GPlus, 671, check)
      call createCurrent(P_Z, P_H, P_WMinus, P_GPlus, 130, check)
      call createCurrent(P_WPlus, P_A, P_Z, P_WMinus, 1453, check)
      call createCurrent(P_g, P_g, P_A, P_g, 1675, check)
      call createCurrent(P_sAnti, P_c, P_GMinus, 951, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_Z, 1036, check)
      call createCurrent(P_WMinus, P_t, P_bAnti, 935, check)
      call createCurrent(P_u, P_dAnti, P_WpMinus, 1124, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, 338, check)
      call createCurrent(P_H, P_muMinus, P_muPlus, 359, check)
      call createCurrent(P_eMinus, P_WpPlus, P_nu_eAnti, 662, check)
      call createCurrent(P_d, P_sAnti, P_G0, 137, check)
      call createCurrent(P_nu_muAnti, P_eMinus, P_WpPlus, 1087, check)
      call createCurrent(P_H, P_g, P_g, 1670, check)
      call createCurrent(P_tauMinus, P_H, P_tauPlus, 270, check)
      call createCurrent(P_nu_e, P_nu_eAnti, 1528, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, 628, check)
      call createCurrent(P_nu_eAnti, P_Z, P_nu_e, 829, check)
      call createCurrent(P_b, P_Z, P_bAnti, 1459, check)
      call createCurrent(P_d, P_dAnti, P_G0, 1447, check)
      call createCurrent(P_cAnti, P_WPlus, P_s, 118, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, 1025, check)
      call createCurrent(P_g, P_WpPlus, P_g, P_WMinus, 1561, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_A, 410, check)
      call createCurrent(P_d, P_uAnti, P_WPlus, 304, check)
      call createCurrent(P_Zp, P_c, P_tAnti, 656, check)
      call createCurrent(P_nu_muAnti, P_GPlus, P_muMinus, 620, check)
      call createCurrent(P_tauPlus, P_WMinus, P_nu_tau, 533, check)
      call createCurrent(P_b, P_tAnti, P_WPlus, 244, check)
      call createCurrent(P_g, P_g, P_WPlus, P_WMinus, 1616, check)
      call createCurrent(P_H, P_ghZ, P_ghZAnti, 631, check)
      call createCurrent(P_WMinus, P_g, P_g, P_WpPlus, 1635, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_Z, 1238, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, 1151, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, 1000, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, 1117, check)
      call createCurrent(P_tauPlus, P_WpMinus, P_nu_tau, 1284, check)
      call createCurrent(P_H, P_Z, P_Z, 46, check)
      call createCurrent(P_G0, P_b, P_bAnti, 613, check)
      call createCurrent(P_GPlus, P_H, P_H, P_GMinus, 293, check)
      call createCurrent(P_H, P_g, P_H, P_g, 1560, check)
      call createCurrent(P_muPlus, P_WpMinus, P_nu_e, 1204, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, 1046, check)
      call createCurrent(P_WMinus, P_nu_tau, P_tauPlus, 119, check)
      call createCurrent(P_muMinus, P_nu_eAnti, P_WpPlus, 974, check)
      call createCurrent(P_u, P_uAnti, P_Zp, 1409, check)
      call createCurrent(P_s, P_bAnti, P_Zp, 941, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, 972, check)
      call createCurrent(P_WPlus, P_WMinus, P_WPlus, P_WMinus, 1263, check)
      call createCurrent(P_g, P_Z, P_Z, P_g, 1565, check)
      call createCurrent(P_nu_tau, P_Z, P_nu_tauAnti, 916, check)
      call createCurrent(P_G0, P_dAnti, P_s, 758, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_A, 687, check)
      call createCurrent(P_nu_tau, P_WpMinus, P_ePlus, 365, check)
      call createCurrent(P_c, P_cAnti, P_H, 872, check)
      call createCurrent(P_bAnti, P_t, P_WMinus, 807, check)
      call createCurrent(P_bAnti, P_H, P_b, 366, check)
      call createCurrent(P_g, P_g, P_Zp, 1644, check)
      call createCurrent(P_Zp, P_s, P_dAnti, 976, check)
      call createCurrent(P_WPlus, P_eMinus, P_nu_eAnti, 514, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, P_A, 1192, check)
      call createCurrent(P_uAnti, P_WPlus, P_d, 1249, check)
      call createCurrent(P_tauPlus, P_GMinus, P_nu_tau, 362, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, 353, check)
      call createCurrent(P_c, P_WMinus, P_dAnti, 792, check)
      call createCurrent(P_Zp, P_g, P_g, 1657, check)
      call createCurrent(P_nu_e, P_tauPlus, P_WpMinus, 1461, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_H, 653, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_G0, 738, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GPlus, 156, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, 867, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, 600, check)
      call createCurrent(P_GPlus, P_d, P_uAnti, 882, check)
      call createCurrent(P_eMinus, P_ePlus, 1518, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, 1083, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_G0, 99, check)
      call createCurrent(P_dAnti, P_d, P_H, 1360, check)
      call createCurrent(P_WpMinus, P_tauPlus, P_nu_e, 1098, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, 413, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, 1045, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_Z, 477, check)
      call createCurrent(P_Z, P_A, P_WMinus, P_WPlus, 1311, check)
      call createCurrent(P_d, P_Zp, P_sAnti, 385, check)
      call createCurrent(P_tauMinus, P_ePlus, P_Zp, 1445, check)
      call createCurrent(P_eMinus, P_Zp, P_ePlus, 638, check)
      call createCurrent(P_tauPlus, P_Zp, P_muMinus, 25, check)
      call createCurrent(P_Z, P_H, P_Z, 1219, check)
      call createCurrent(P_A, P_tAnti, P_t, 1084, check)
      call createCurrent(P_nu_mu, P_WpMinus, P_tauPlus, 876, check)
      call createCurrent(P_eMinus, P_WpPlus, P_nu_tauAnti, 377, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, 1231, check)
      call createCurrent(P_nu_e, P_muPlus, P_WpMinus, 1013, check)
      call createCurrent(P_GPlus, P_nu_tauAnti, P_tauMinus, 1462, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_A, 483, check)
      call createCurrent(P_Z, P_d, P_dAnti, 686, check)
      call createCurrent(P_g, P_A, P_Zp, P_g, 1590, check)
      call createCurrent(P_s, P_Zp, P_bAnti, 680, check)
      call createCurrent(P_tAnti, P_t, P_Zp, 480, check)
      call createCurrent(P_g, P_g, P_WpMinus, P_WpPlus, 1566, check)
      call createCurrent(P_b, P_A, P_bAnti, 822, check)
      call createCurrent(P_WMinus, P_WPlus, P_WPlus, P_WMinus, 1373, check)
      call createCurrent(P_GMinus, P_c, P_sAnti, 1262, check)
      call createCurrent(P_WpMinus, P_c, P_sAnti, 311, check)
      call createCurrent(P_WPlus, P_H, P_Z, P_GMinus, 1108, check)
      call createCurrent(P_g, P_c, P_cAnti, 1280, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, 1251, check)
      call createCurrent(P_GMinus, P_H, P_GPlus, P_H, 1118, check)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_GMinus, 523, check)
      call createCurrent(P_cAnti, P_s, P_WPlus, 1185, check)
      call createCurrent(P_bAnti, P_s, P_Zp, 1005, check)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_GMinus, 1089, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_A, 1416, check)
      call createCurrent(P_sAnti, P_d, P_G0, 358, check)
      call createCurrent(P_c, P_WpMinus, P_bAnti, 966, check)
      call createCurrent(P_A, P_WPlus, P_H, P_GMinus, 586, check)
      call createCurrent(P_Zp, P_c, P_uAnti, 1446, check)
      call createCurrent(P_G0, P_GPlus, P_G0, P_GMinus, 1332, check)
      call createCurrent(P_tauPlus, P_muMinus, P_Zp, 1019, check)
      call createCurrent(P_GMinus, P_G0, P_Z, P_WPlus, 207, check)
      call createCurrent(P_WMinus, P_GPlus, 1535, check)
      call createCurrent(P_Zp, P_u, P_cAnti, 479, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_Z, 1264, check)
      call createCurrent(P_g, P_sAnti, P_s, 460, check)
      call createCurrent(P_ePlus, P_nu_e, P_WMinus, 1305, check)
      call createCurrent(P_GMinus, P_WPlus, 1510, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, 538, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WpPlus, 751, check)
      call createCurrent(P_A, P_t, P_tAnti, 214, check)
      call createCurrent(P_sAnti, P_GMinus, P_u, 106, check)
      call createCurrent(P_b, P_G0, P_bAnti, 251, check)
      call createCurrent(P_nu_tau, P_GMinus, P_tauPlus, 985, check)
      call createCurrent(P_GPlus, P_s, P_uAnti, 1317, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, 1348, check)
      call createCurrent(P_Z, P_s, P_sAnti, 884, check)
      call createCurrent(P_nu_tau, P_WMinus, P_tauPlus, 66, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, 1490, check)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_GMinus, 1093, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_A, 1011, check)
      call createCurrent(P_sAnti, P_s, P_g, 501, check)
      call createCurrent(P_WPlus, P_GMinus, 1502, check)
      call createCurrent(P_WpMinus, P_WPlus, P_g, P_g, 1651, check)
      call createCurrent(P_A, P_g, P_Z, P_g, 1563, check)
      call createCurrent(P_WPlus, P_WPlus, P_WMinus, P_WMinus, 1368, check)
      call createCurrent(P_cAnti, P_Zp, P_u, 402, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, 1474, check)
      call createCurrent(P_nu_eAnti, P_WpPlus, P_muMinus, 141, check)
      call createCurrent(P_tAnti, P_t, P_g, 932, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, 1097, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, 1338, check)
      call createCurrent(P_WpPlus, P_nu_tauAnti, P_tauMinus, 1363, check)
      call createCurrent(P_H, P_Z, P_GPlus, P_WMinus, 1144, check)
      call createCurrent(P_s, P_WPlus, P_uAnti, 1085, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, 1350, check)
      call createCurrent(P_GMinus, P_WPlus, P_GPlus, P_WMinus, 797, check)
      call createCurrent(P_eMinus, P_ePlus, P_G0, 1174, check)
      call createCurrent(P_g, P_Z, P_g, P_Zp, 1558, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_G0, 1147, check)
      call createCurrent(P_H, P_bAnti, P_b, 438, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, 128, check)
      call createCurrent(P_t, P_WpMinus, P_sAnti, 416, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_H, 623, check)
      call createCurrent(P_dAnti, P_G0, P_s, 1274, check)
      call createCurrent(P_uAnti, P_u, P_Z, 549, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_G0, 783, check)
      call createCurrent(P_tAnti, P_b, P_WpPlus, 360, check)
      call createCurrent(P_GPlus, P_Z, P_H, P_WMinus, 889, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, 547, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_Z, 599, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, 690, check)
      call createCurrent(P_GMinus, P_H, P_H, P_GPlus, 601, check)
      call createCurrent(P_nu_mu, P_Z, P_nu_muAnti, 704, check)
      call createCurrent(P_WpPlus, P_cAnti, P_d, 17, check)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_GMinus, 124, check)
      call createCurrent(P_sAnti, P_s, P_Zp, 1415, check)
      call createCurrent(P_u, P_WMinus, P_dAnti, 922, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, 420, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, 149, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_H, 729, check)
      call createCurrent(P_H, P_s, P_sAnti, 1109, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, 1495, check)
      call createCurrent(P_tauMinus, P_Z, P_tauPlus, 1283, check)
      call createCurrent(P_A, P_g, P_g, P_A, 1674, check)
      call createCurrent(P_GMinus, P_nu_mu, P_muPlus, 811, check)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_GPlus, 1419, check)
      call createCurrent(P_eMinus, P_ePlus, P_H, 550, check)
      call createCurrent(P_A, P_bAnti, P_b, 1460, check)
      call createCurrent(P_g, P_WpPlus, P_WpMinus, P_g, 1604, check)
      call createCurrent(P_ePlus, P_eMinus, 1500, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_Z, 688, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, 1315, check)
      call createCurrent(P_Zp, P_g, P_Z, P_g, 1615, check)
      call createCurrent(P_g, P_Z, P_g, P_A, 1640, check)
      call createCurrent(P_ePlus, P_WpMinus, P_nu_mu, 1387, check)
      call createCurrent(P_WpMinus, P_tauPlus, P_nu_mu, 328, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, 299, check)
      call createCurrent(P_t, P_bAnti, P_GMinus, 231, check)
      call createCurrent(P_bAnti, P_GMinus, P_t, 172, check)
      call createCurrent(P_Z, P_tauMinus, P_tauPlus, 1321, check)
      call createCurrent(P_G0, P_H, P_H, P_G0, 844, check)
      call createCurrent(P_GMinus, P_H, P_GPlus, 949, check)
      call createCurrent(P_dAnti, P_d, P_Zp, 723, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, 1222, check)
      call createCurrent(P_WMinus, P_WPlus, P_g, P_g, 1544, check)
      call createCurrent(P_Z, P_A, P_WPlus, P_WMinus, 213, check)
      call createCurrent(P_H, P_WMinus, P_A, P_GPlus, 458, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_GMinus, 518, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_G0, 668, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_G0, 1173, check)
      call createCurrent(P_Zp, P_t, P_cAnti, 411, check)
      call createCurrent(P_sAnti, P_g, P_s, 1188, check)
      call createCurrent(P_G0, P_tauMinus, P_tauPlus, 1245, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, 1524, check)
      call createCurrent(P_WpMinus, P_t, P_dAnti, 1081, check)
      call createCurrent(P_G0, P_s, P_sAnti, 937, check)
      call createCurrent(P_Zp, P_eMinus, P_tauPlus, 1053, check)
      call createCurrent(P_Z, P_H, P_G0, 1366, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, 363, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, 1509, check)
      call createCurrent(P_Z, P_muPlus, P_muMinus, 555, check)
      call createCurrent(P_WpMinus, P_sAnti, P_c, 1152, check)
      call createCurrent(P_Zp, P_eMinus, P_ePlus, 1095, check)
      call createCurrent(P_Z, P_g, P_A, P_g, 1654, check)
      call createCurrent(P_tAnti, P_t, P_G0, 18, check)
      call createCurrent(P_WpMinus, P_g, P_g, P_WPlus, 1549, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghWm, 861, check)
      call createCurrent(P_Zp, P_u, P_tAnti, 1304, check)
      call createCurrent(P_s, P_G0, P_sAnti, 633, check)
      call createCurrent(P_cAnti, P_d, P_WPlus, 1063, check)
      call createCurrent(P_g, P_g, P_WPlus, P_WpMinus, 1599, check)
      call createCurrent(P_Z, P_G0, P_WMinus, P_GPlus, 945, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, 1075, check)
      call createCurrent(P_GPlus, P_WMinus, P_GMinus, P_WPlus, 764, check)
      call createCurrent(P_tAnti, P_t, P_H, 1161, check)
      call createCurrent(P_Zp, P_tAnti, P_c, 1384, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WPlus, 1429, check)
      call createCurrent(P_tauPlus, P_eMinus, P_Zp, 1335, check)
      call createCurrent(P_A, P_Z, P_GPlus, P_GMinus, 1008, check)
      call createCurrent(P_d, P_A, P_dAnti, 59, check)
      call createCurrent(P_c, P_uAnti, P_Zp, 1094, check)
      call createCurrent(P_Zp, P_tAnti, P_t, 626, check)
      call createCurrent(P_d, P_sAnti, P_Zp, 1043, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, 254, check)
      call createCurrent(P_Zp, P_cAnti, P_c, 1342, check)
      call createCurrent(P_H, P_H, P_G0, P_G0, 364, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_Z, 956, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, 1004, check)
      call createCurrent(P_G0, P_G0, P_H, P_H, 257, check)
      call createCurrent(P_tAnti, P_A, P_t, 1390, check)
      call createCurrent(P_A, P_g, P_g, P_Zp, 1666, check)
      call createCurrent(P_c, P_WMinus, P_sAnti, 1082, check)
      call createCurrent(P_u, P_Z, P_uAnti, 1260, check)
      call createCurrent(P_g, P_GPlus, P_g, P_GMinus, 1573, check)
      call createCurrent(P_s, P_sAnti, P_A, 1233, check)
      call createCurrent(P_t, P_tAnti, P_g, 785, check)
      call createCurrent(P_uAnti, P_s, P_WPlus, 596, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, 1488, check)
      call createCurrent(P_Zp, P_b, P_dAnti, 387, check)
      call createCurrent(P_Z, P_nu_muAnti, P_nu_mu, 1119, check)
      call createCurrent(P_Z, P_bAnti, P_b, 762, check)
      call createCurrent(P_WPlus, P_H, P_H, P_WMinus, 554, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GPlus, 1194, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_A, 50, check)
      call createCurrent(P_g, P_WMinus, P_WpPlus, P_g, 1577, check)
      call createCurrent(P_WMinus, P_GPlus, P_H, P_A, 269, check)
      call createCurrent(P_Z, P_dAnti, P_d, 1433, check)
      call createCurrent(P_b, P_cAnti, P_WpPlus, 1116, check)
      call createCurrent(P_A, P_WMinus, P_A, P_WPlus, 482, check)
      call createCurrent(P_nu_tauAnti, P_WpPlus, P_muMinus, 291, check)
      call createCurrent(P_A, P_c, P_cAnti, 695, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, 1272, check)
      call createCurrent(P_A, P_uAnti, P_u, 592, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_A, 780, check)
      call createCurrent(P_Zp, P_cAnti, P_u, 433, check)
      call createCurrent(P_WpPlus, P_nu_tauAnti, P_eMinus, 1314, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_Z, 239, check)
      call createCurrent(P_Z, P_g, P_Z, P_g, 1605, check)
      call createCurrent(P_WpPlus, P_muMinus, P_nu_eAnti, 495, check)
      call createCurrent(P_GPlus, P_A, P_H, P_WMinus, 636, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WPlus, 182, check)
      call createCurrent(P_g, P_Z, P_Zp, P_g, 1576, check)
      call createCurrent(P_g, P_WMinus, P_g, P_WpPlus, 1664, check)
      call createCurrent(P_s, P_g, P_sAnti, 953, check)
      call createCurrent(P_G0, P_G0, P_Z, P_Z, 1032, check)
      call createCurrent(P_u, P_sAnti, P_WMinus, 193, check)
      call createCurrent(P_uAnti, P_Zp, P_u, 575, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, 1370, check)
      call createCurrent(P_WpMinus, P_bAnti, P_t, 940, check)
      call createCurrent(P_A, P_g, P_g, P_g, 1578, check)
      call createCurrent(P_d, P_uAnti, P_WpPlus, 1060, check)
      call createCurrent(P_Zp, P_dAnti, P_s, 317, check)
      call createCurrent(P_nu_e, P_GMinus, P_ePlus, 1020, check)
      call createCurrent(P_tAnti, P_WPlus, P_b, 96, check)
      call createCurrent(P_muMinus, P_muPlus, P_H, 1055, check)
      call createCurrent(P_d, P_bAnti, P_Zp, 188, check)
      call createCurrent(P_dAnti, P_d, 1504, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_G0, 1001, check)
      call createCurrent(P_s, P_sAnti, P_Z, 121, check)
      call createCurrent(P_g, P_H, P_g, 1672, check)
      call createCurrent(P_Zp, P_s, P_bAnti, 689, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, 198, check)
      call createCurrent(P_sAnti, P_Zp, P_b, 904, check)
      call createCurrent(P_g, P_d, P_dAnti, 3, check)
      call createCurrent(P_cAnti, P_g, P_c, 134, check)
      call createCurrent(P_A, P_cAnti, P_c, 125, check)
      call createCurrent(P_GMinus, P_Z, P_A, P_GPlus, 1397, check)
      call createCurrent(P_WpPlus, P_g, P_g, P_WpMinus, 1634, check)
      call createCurrent(P_g, P_tAnti, P_t, 858, check)
      call createCurrent(P_s, P_dAnti, P_Zp, 1049, check)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_G0, 1149, check)
      call createCurrent(P_H, P_GMinus, P_Z, P_WPlus, 84, check)
      call createCurrent(P_d, P_uAnti, P_GPlus, 401, check)
      call createCurrent(P_g, P_g, P_g, P_Zp, 1596, check)
      call createCurrent(P_H, P_GPlus, P_WMinus, 535, check)
      call createCurrent(P_H, P_tauMinus, P_tauPlus, 197, check)
      call createCurrent(P_t, P_g, P_tAnti, 1150, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, 874, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, 1016, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, 749, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_A, 903, check)
      call createCurrent(P_WpMinus, P_nu_tau, P_muPlus, 1056, check)
      call createCurrent(P_H, P_GMinus, P_WPlus, P_Z, 246, check)
      call createCurrent(P_G0, P_WPlus, P_Z, P_GMinus, 355, check)
      call createCurrent(P_WPlus, P_A, P_A, P_WMinus, 1176, check)
      call createCurrent(P_WMinus, P_WpPlus, P_g, P_g, 1574, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, 335, check)
      call createCurrent(P_nu_mu, P_WpMinus, P_ePlus, 928, check)
      call createCurrent(P_G0, P_u, P_uAnti, 851, check)
      call createCurrent(P_muPlus, P_muMinus, 1525, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_A, 666, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, 1365, check)
      call createCurrent(P_uAnti, P_c, P_Zp, 1214, check)
      call createCurrent(P_b, P_dAnti, P_Zp, 553, check)
      call createCurrent(P_uAnti, P_G0, P_u, 55, check)
      call createCurrent(P_A, P_A, P_GPlus, P_GMinus, 74, check)
      call createCurrent(P_dAnti, P_d, P_Z, 672, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, 201, check)
      call createCurrent(P_Zp, P_ePlus, P_muMinus, 205, check)
      call createCurrent(P_sAnti, P_d, P_Zp, 993, check)
      call createCurrent(P_nu_mu, P_tauPlus, P_WpMinus, 91, check)
      call createCurrent(P_bAnti, P_b, P_Zp, 1110, check)
      call createCurrent(P_muMinus, P_Zp, P_ePlus, 815, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, 186, check)
      call createCurrent(P_WpPlus, P_eMinus, P_nu_eAnti, 621, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, 647, check)
      call createCurrent(P_Z, P_G0, P_GPlus, P_WMinus, 339, check)
      call createCurrent(P_H, P_H, P_g, P_g, 1556, check)
      call createCurrent(P_WpPlus, P_eMinus, P_nu_tauAnti, 1483, check)
      call createCurrent(P_Z, P_b, P_bAnti, 294, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_Z, 426, check)
      call createCurrent(P_t, P_tAnti, P_H, 1039, check)
      call createCurrent(P_WPlus, P_G0, P_Z, P_GMinus, 1, check)
      call createCurrent(P_Z, P_GMinus, P_G0, P_WPlus, 1408, check)
      call createCurrent(P_nu_tauAnti, P_WpPlus, P_eMinus, 1014, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, 449, check)
      call createCurrent(P_WMinus, P_nu_e, P_ePlus, 286, check)
      call createCurrent(P_H, P_WMinus, P_H, P_WPlus, 649, check)
      call createCurrent(P_g, P_u, P_uAnti, 1295, check)
      call createCurrent(P_eMinus, P_A, P_ePlus, 775, check)
      call createCurrent(P_tAnti, P_WpPlus, P_s, 1172, check)
      call createCurrent(P_nu_tauAnti, P_Z, P_nu_tau, 337, check)
      call createCurrent(P_muMinus, P_WpPlus, P_nu_tauAnti, 754, check)
      call createCurrent(P_Zp, P_Zp, 1521, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, 381, check)
      call createCurrent(P_GMinus, P_GPlus, P_H, 267, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_G0, 958, check)
      call createCurrent(P_A, P_GMinus, P_A, P_GPlus, 1369, check)
      call createCurrent(P_sAnti, P_s, P_A, 459, check)
      call createCurrent(P_tAnti, P_d, P_WpPlus, 437, check)
      call createCurrent(P_muPlus, P_tauMinus, P_Zp, 717, check)
      call createCurrent(P_H, P_Z, P_H, P_Z, 429, check)
      call createCurrent(P_WpPlus, P_tAnti, P_b, 187, check)
      call createCurrent(P_WpPlus, P_uAnti, P_s, 988, check)
      call createCurrent(P_eMinus, P_ePlus, P_Z, 1343, check)
      call createCurrent(P_G0, P_Z, P_GPlus, P_WMinus, 268, check)
      call createCurrent(P_G0, P_G0, P_WPlus, P_WMinus, 1392, check)
      call createCurrent(P_GMinus, P_ePlus, P_nu_e, 1066, check)
      call createCurrent(P_G0, P_A, P_GPlus, P_WMinus, 1421, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_H, 777, check)
      call createCurrent(P_Zp, P_Z, P_g, P_g, 1609, check)
      call createCurrent(P_s, P_dAnti, P_H, 1256, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, 902, check)
      call createCurrent(P_b, P_uAnti, P_WpPlus, 393, check)
      call createCurrent(P_cAnti, P_c, P_g, 983, check)
      call createCurrent(P_GPlus, P_uAnti, P_d, 487, check)
      call createCurrent(P_Zp, P_eMinus, P_muPlus, 295, check)
      call createCurrent(P_GMinus, P_G0, P_G0, P_GPlus, 1494, check)
      call createCurrent(P_GMinus, P_sAnti, P_u, 732, check)
      call createCurrent(P_Zp, P_ePlus, P_eMinus, 959, check)
      call createCurrent(P_uAnti, P_GPlus, P_d, 1091, check)
      call createCurrent(P_u, P_GMinus, P_sAnti, 900, check)
      call createCurrent(P_A, P_g, P_A, P_g, 1647, check)
      call createCurrent(P_WMinus, P_H, P_GPlus, P_Z, 389, check)
      call createCurrent(P_A, P_sAnti, P_s, 1048, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WpMinus, 180, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, 1169, check)
      call createCurrent(P_d, P_WpPlus, P_uAnti, 1417, check)
      call createCurrent(P_sAnti, P_u, P_WpMinus, 432, check)
      call createCurrent(P_d, P_dAnti, P_Z, 191, check)
      call createCurrent(P_Zp, P_tauPlus, P_tauMinus, 1325, check)
      call createCurrent(P_nu_e, P_WpMinus, P_tauPlus, 840, check)
      call createCurrent(P_WpMinus, P_tauPlus, P_nu_tau, 1143, check)
      call createCurrent(P_dAnti, P_H, P_d, 110, check)
      call createCurrent(P_nu_muAnti, P_WPlus, P_muMinus, 305, check)
      call createCurrent(P_tAnti, P_H, P_t, 865, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, 919, check)
      call createCurrent(P_cAnti, P_s, P_GPlus, 466, check)
      call createCurrent(P_G0, P_A, P_GMinus, P_WPlus, 597, check)
      call createCurrent(P_Z, P_A, P_g, P_g, 1572, check)
      call createCurrent(P_WpMinus, P_ePlus, P_nu_e, 148, check)
      call createCurrent(P_GMinus, P_A, P_H, P_WPlus, 486, check)
      call createCurrent(P_Z, P_GMinus, P_A, P_GPlus, 64, check)
      call createCurrent(P_GMinus, P_u, P_dAnti, 221, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, 34, check)
      call createCurrent(P_WpMinus, P_WpPlus, 1533, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, 160, check)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_G0, 1234, check)
      call createCurrent(P_cAnti, P_u, P_Zp, 569, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_Z, 1059, check)
      call createCurrent(P_sAnti, P_G0, P_s, 1189, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_A, 396, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, 712, check)
      call createCurrent(P_cAnti, P_t, P_Zp, 510, check)
      call createCurrent(P_muMinus, P_Z, P_muPlus, 384, check)
      call createCurrent(P_G0, P_G0, P_WMinus, P_WPlus, 226, check)
      call createCurrent(P_b, P_Zp, P_sAnti, 857, check)
      call createCurrent(P_b, P_WpPlus, P_tAnti, 1041, check)
      call createCurrent(P_GMinus, P_c, P_dAnti, 593, check)
      call createCurrent(P_b, P_bAnti, P_A, 883, check)
      call createCurrent(P_c, P_bAnti, P_WpMinus, 946, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, 1491, check)
      call createCurrent(P_WMinus, P_GPlus, P_GMinus, P_WPlus, 1106, check)
      call createCurrent(P_g, P_g, P_g, P_g, 1290, check)
      call createCurrent(P_dAnti, P_WpMinus, P_c, 584, check)
      call createCurrent(P_tAnti, P_b, P_WPlus, 1134, check)
      call createCurrent(P_WpMinus, P_u, P_dAnti, 250, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WPlus, 881, check)
      call createCurrent(P_H, P_Z, P_WPlus, P_GMinus, 69, check)
      call createCurrent(P_g, P_WMinus, P_WPlus, P_g, 1594, check)
      call createCurrent(P_WpPlus, P_b, P_cAnti, 89, check)
      call createCurrent(P_Z, P_H, P_H, P_Z, 1195, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, 658, check)
      call createCurrent(P_t, P_WMinus, P_bAnti, 1481, check)
      call createCurrent(P_WPlus, P_cAnti, P_d, 934, check)
      call createCurrent(P_WpMinus, P_t, P_bAnti, 371, check)
      call createCurrent(P_H, P_d, P_dAnti, 915, check)
      call createCurrent(P_Zp, P_dAnti, P_b, 1420, check)
      call createCurrent(P_Z, P_GMinus, P_H, P_WPlus, 474, check)
      call createCurrent(P_WpMinus, P_u, P_bAnti, 1308, check)
      call createCurrent(P_tAnti, P_WpPlus, P_b, 320, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, 1293, check)
      call createCurrent(P_nu_eAnti, P_WpPlus, P_tauMinus, 926, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, 1162, check)
      call createCurrent(P_dAnti, P_Zp, P_s, 383, check)
      call createCurrent(P_dAnti, P_c, P_WpMinus, 539, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_H, 1347, check)
      call createCurrent(P_H, P_GMinus, P_H, P_GPlus, 29, check)
      call createCurrent(P_bAnti, P_c, P_WpMinus, 1394, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, 1443, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, 49, check)
      call createCurrent(P_bAnti, P_A, P_b, 1193, check)
      call createCurrent(P_bAnti, P_Zp, P_s, 917, check)
      call createCurrent(P_G0, P_t, P_tAnti, 44, check)
      call createCurrent(P_cAnti, P_c, P_G0, 824, check)
      call createCurrent(P_Zp, P_d, P_sAnti, 105, check)
      call createCurrent(P_H, P_WMinus, P_GPlus, P_A, 911, check)
      call createCurrent(P_bAnti, P_g, P_b, 588, check)
      call createCurrent(P_WMinus, P_G0, P_Z, P_GPlus, 1484, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, 1148, check)
      call createCurrent(P_muPlus, P_Zp, P_muMinus, 100, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_A, 734, check)
      call createCurrent(P_muMinus, P_H, P_muPlus, 1253, check)
      call createCurrent(P_nu_e, P_WpMinus, P_ePlus, 800, check)
      call createCurrent(P_Zp, P_tauPlus, P_eMinus, 15, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_Z, 561, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, 414, check)
      call createCurrent(P_GPlus, P_Z, P_A, P_GMinus, 236, check)
      call createCurrent(P_g, P_uAnti, P_u, 499, check)
      call createCurrent(P_dAnti, P_s, P_H, 1497, check)
      call createCurrent(P_Z, P_H, P_Z, P_H, 1492, check)
      call createCurrent(P_muMinus, P_G0, P_muPlus, 709, check)
      call createCurrent(P_Zp, P_ePlus, P_tauMinus, 1145, check)
      call createCurrent(P_WpMinus, P_bAnti, P_u, 820, check)
      call createCurrent(P_Z, P_Zp, P_g, P_g, 1676, check)
      call createCurrent(P_H, P_ghWmAnti, P_ghWm, 173, check)
      call createCurrent(P_nu_mu, P_GMinus, P_muPlus, 862, check)
      call createCurrent(P_WpMinus, P_muPlus, P_nu_mu, 581, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_H, 113, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_H, 530, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, 57, check)
      call createCurrent(P_G0, P_Z, P_GMinus, P_WPlus, 351, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, 1261, check)
      call createCurrent(P_sAnti, P_s, P_Z, 367, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WpPlus, 818, check)
      call createCurrent(P_g, P_Zp, P_Zp, P_g, 1653, check)
      call createCurrent(P_g, P_Z, P_A, P_g, 1589, check)
      call createCurrent(P_muPlus, P_Z, P_muMinus, 1388, check)
      call createCurrent(P_WpPlus, P_nu_eAnti, P_eMinus, 104, check)
      call createCurrent(P_dAnti, P_GMinus, P_c, 81, check)
      call createCurrent(P_c, P_tAnti, P_Zp, 663, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, 442, check)
      call createCurrent(P_Zp, P_b, P_bAnti, 1385, check)
      call createCurrent(P_Zp, P_Zp, P_g, P_g, 1543, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, P_Z, 873, check)
      call createCurrent(P_Z, P_cAnti, P_c, 1356, check)
      call createCurrent(P_muPlus, P_G0, P_muMinus, 868, check)
      call createCurrent(P_nu_tauAnti, P_WPlus, P_tauMinus, 1211, check)
      call createCurrent(P_H, P_G0, P_G0, P_H, 1163, check)
      call createCurrent(P_nu_mu, P_WpMinus, P_muPlus, 856, check)
      call createCurrent(P_cAnti, P_H, P_c, 938, check)
      call createCurrent(P_H, P_H, 1507, check)
      call createCurrent(P_G0, P_G0, P_H, 1040, check)
      call createCurrent(P_WpMinus, P_WpPlus, P_g, P_g, 1606, check)
      call createCurrent(P_bAnti, P_Zp, P_b, 769, check)
      call createCurrent(P_s, P_cAnti, P_GPlus, 629, check)
      call createCurrent(P_cAnti, P_c, P_A, 345, check)
      call createCurrent(P_WpMinus, P_nu_mu, P_ePlus, 457, check)
      call createCurrent(P_WpPlus, P_nu_eAnti, P_muMinus, 827, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, 1414, check)
      call createCurrent(P_Zp, P_dAnti, P_d, 395, check)
      call createCurrent(P_nu_tauAnti, P_WpPlus, P_tauMinus, 1007, check)
      call createCurrent(P_t, P_tAnti, P_Zp, 212, check)
      call createCurrent(P_tauMinus, P_G0, P_tauPlus, 39, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_H, 507, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghWp, 1281, check)
      call createCurrent(P_t, P_Zp, P_cAnti, 1351, check)
      call createCurrent(P_GMinus, P_nu_e, P_ePlus, 158, check)
      call createCurrent(P_WMinus, P_ePlus, P_nu_e, 618, check)
      call createCurrent(P_WpPlus, P_g, P_WMinus, P_g, 1631, check)
      call createCurrent(P_g, P_WpMinus, P_WpPlus, P_g, 1551, check)
      call createCurrent(P_t, P_dAnti, P_WpMinus, 577, check)
      call createCurrent(P_cAnti, P_GPlus, P_s, 288, check)
      call createCurrent(P_uAnti, P_u, P_A, 1359, check)
      call createCurrent(P_tAnti, P_G0, P_t, 349, check)
      call createCurrent(P_muPlus, P_nu_mu, P_GMinus, 280, check)
      call createCurrent(P_Z, P_Z, P_GMinus, P_GPlus, 700, check)
      call createCurrent(P_Z, P_nu_eAnti, P_nu_e, 875, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, 1328, check)
      call createCurrent(P_tAnti, P_Z, P_t, 1377, check)
      call createCurrent(P_WMinus, P_u, P_dAnti, 1227, check)
      call createCurrent(P_G0, P_Z, P_Z, P_G0, 217, check)
      call createCurrent(P_d, P_dAnti, P_H, 1498, check)
      call createCurrent(P_cAnti, P_WpPlus, P_s, 447, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Z, 1489, check)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_G0, 1362, check)
      call createCurrent(P_Zp, P_u, P_uAnti, 1258, check)
      call createCurrent(P_cAnti, P_WpPlus, P_b, 679, check)
      call createCurrent(P_nu_mu, P_WMinus, P_muPlus, 415, check)
      call createCurrent(P_d, P_WPlus, P_cAnti, 878, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WPlus, 708, check)
      call createCurrent(P_g, P_Zp, P_Z, P_g, 1671, check)
      call createCurrent(P_A, P_A, P_WMinus, P_WPlus, 1319, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_Z, 595, check)
      call createCurrent(P_A, P_GMinus, P_H, P_WPlus, 790, check)
      call createCurrent(P_ePlus, P_WpMinus, P_nu_tau, 776, check)
      call createCurrent(P_g, P_A, P_A, P_g, 1641, check)
      call createCurrent(P_WMinus, P_c, P_dAnti, 140, check)
      call createCurrent(P_s, P_H, P_dAnti, 409, check)
      call createCurrent(P_sAnti, P_Z, P_s, 706, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, 1341, check)
      call createCurrent(P_g, P_g, P_WMinus, P_WPlus, 1627, check)
      call createCurrent(P_WpPlus, P_uAnti, P_b, 1470, check)
      call createCurrent(P_G0, P_H, P_G0, P_H, 1436, check)
      call createCurrent(P_g, P_WPlus, P_WMinus, P_g, 1588, check)
      call createCurrent(P_Z, P_muMinus, P_muPlus, 603, check)
      call createCurrent(P_ghWp, P_H, P_ghWpAnti, 714, check)
      call createCurrent(P_Zp, P_d, P_dAnti, 1297, check)
      call createCurrent(P_WMinus, P_WPlus, P_H, 580, check)
      call createCurrent(P_b, P_tAnti, P_GPlus, 38, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_A, 1241, check)
      call createCurrent(P_sAnti, P_d, P_H, 228, check)
      call createCurrent(P_dAnti, P_A, P_d, 789, check)
      call createCurrent(P_GPlus, P_WMinus, 1512, check)
      call createCurrent(P_H, P_GMinus, P_A, P_WPlus, 40, check)
      call createCurrent(P_Z, P_tAnti, P_t, 210, check)
      call createCurrent(P_WpPlus, P_muMinus, P_nu_muAnti, 1236, check)
      call createCurrent(P_b, P_tAnti, P_WpPlus, 204, check)
      call createCurrent(P_bAnti, P_WpMinus, P_t, 199, check)
      call createCurrent(P_ePlus, P_nu_tau, P_WpMinus, 682, check)
      call createCurrent(P_tauMinus, P_GPlus, P_nu_tauAnti, 907, check)
      call createCurrent(P_Z, P_G0, P_WPlus, P_GMinus, 573, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, 849, check)
      call createCurrent(P_ePlus, P_Zp, P_eMinus, 374, check)
      call createCurrent(P_s, P_sAnti, 1511, check)
      call createCurrent(P_t, P_Zp, P_uAnti, 880, check)
      call createCurrent(P_WPlus, P_g, P_g, P_WpMinus, 1546, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_H, 206, check)
      call createCurrent(P_WPlus, P_d, P_uAnti, 615, check)
      call createCurrent(P_WpPlus, P_b, P_tAnti, 810, check)
      call createCurrent(P_u, P_dAnti, P_GMinus, 155, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_Z, 540, check)
      call createCurrent(P_s, P_cAnti, P_WpPlus, 1228, check)
      call createCurrent(P_g, P_G0, P_g, P_G0, 1658, check)
      call createCurrent(P_dAnti, P_s, P_G0, 652, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_Z, 249, check)
      call createCurrent(P_g, P_cAnti, P_c, 1435, check)
      call createCurrent(P_g, P_Zp, P_g, P_Zp, 1625, check)
      call createCurrent(P_sAnti, P_c, P_WMinus, 670, check)
      call createCurrent(P_bAnti, P_t, P_GMinus, 168, check)
      call createCurrent(P_H, P_WMinus, P_Z, P_GPlus, 417, check)
      call createCurrent(P_A, P_WMinus, P_G0, P_GPlus, 696, check)
      call createCurrent(P_Zp, P_t, P_tAnti, 403, check)
      call createCurrent(P_g, P_g, P_A, P_A, 1617, check)
      call createCurrent(P_WPlus, P_H, P_GMinus, P_A, 943, check)
      call createCurrent(P_WMinus, P_bAnti, P_t, 265, check)
      call createCurrent(P_muPlus, P_muMinus, P_Zp, 607, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_G0, 312, check)
      call createCurrent(P_g, P_WpMinus, P_g, P_WPlus, 1600, check)
      call createCurrent(P_dAnti, P_WMinus, P_c, 843, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, 752, check)
      call createCurrent(P_WPlus, P_d, P_cAnti, 819, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, 1105, check)
      call createCurrent(P_tauPlus, P_WpMinus, P_nu_mu, 1006, check)
      call createCurrent(P_Z, P_G0, P_GMinus, P_WPlus, 721, check)
      call createCurrent(P_A, P_GPlus, P_A, P_GMinus, 1479, check)
      call createCurrent(P_sAnti, P_GMinus, P_c, 750, check)
      call createCurrent(P_WpMinus, P_nu_e, P_muPlus, 32, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, 1403, check)
      call createCurrent(P_GPlus, P_cAnti, P_s, 813, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, 73, check)
      call createCurrent(P_GPlus, P_H, P_GMinus, 309, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, 541, check)
      call createCurrent(P_WpPlus, P_cAnti, P_s, 1477, check)
      call createCurrent(P_nu_eAnti, P_GPlus, P_eMinus, 1312, check)
      call createCurrent(P_Z, P_H, P_GMinus, P_WPlus, 336, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_A, 114, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, 1451, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, 1027, check)
      call createCurrent(P_c, P_Zp, P_cAnti, 1475, check)
      call createCurrent(P_g, P_bAnti, P_b, 701, check)
      call createCurrent(P_sAnti, P_Zp, P_s, 782, check)
      call createCurrent(P_dAnti, P_Zp, P_d, 1155, check)
      call createCurrent(P_GPlus, P_d, P_cAnti, 1353, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, 1378, check)
      call createCurrent(P_H, P_WPlus, P_WMinus, P_H, 400, check)
      call createCurrent(P_sAnti, P_u, P_WMinus, 1271, check)
      call createCurrent(P_uAnti, P_t, P_Zp, 52, check)
      call createCurrent(P_WMinus, P_muPlus, P_nu_mu, 202, check)
      call createCurrent(P_u, P_GMinus, P_dAnti, 624, check)
      call createCurrent(P_tAnti, P_WpPlus, P_d, 342, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, 901, check)
      call createCurrent(P_A, P_GPlus, P_G0, P_WMinus, 122, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_G0, 506, check)
      call createCurrent(P_WMinus, P_sAnti, P_c, 859, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, 984, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, 392, check)
      call createCurrent(P_u, P_tAnti, P_Zp, 144, check)
      call createCurrent(P_bAnti, P_b, P_A, 484, check)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_G0, 719, check)
      call createCurrent(P_G0, P_G0, P_GPlus, P_GMinus, 611, check)
      call createCurrent(P_GMinus, P_muPlus, P_nu_mu, 443, check)
      call createCurrent(P_WpPlus, P_d, P_tAnti, 1376, check)
      call createCurrent(P_GMinus, P_A, P_A, P_GPlus, 1452, check)
      call createCurrent(P_G0, P_muPlus, P_muMinus, 90, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, 677, check)
      call createCurrent(P_eMinus, P_H, P_ePlus, 1286, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, 1186, check)
      call createCurrent(P_b, P_GPlus, P_tAnti, 761, check)
      call createCurrent(P_u, P_sAnti, P_WpMinus, 897, check)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_GPlus, 1456, check)
      call createCurrent(P_H, P_WPlus, P_H, P_WMinus, 1275, check)
      call createCurrent(P_cAnti, P_Zp, P_c, 669, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_Z, 1202, check)
      call createCurrent(P_WpPlus, P_g, P_g, P_WMinus, 1621, check)
      call createCurrent(P_G0, P_GMinus, P_A, P_WPlus, 975, check)
      call createCurrent(P_GMinus, P_GPlus, P_H, P_H, 287, check)
      call createCurrent(P_WMinus, P_A, P_Z, P_WPlus, 278, check)
      call createCurrent(P_b, P_WPlus, P_tAnti, 931, check)
      call createCurrent(P_b, P_bAnti, 1515, check)
      call createCurrent(P_c, P_dAnti, P_WMinus, 427, check)
      call createCurrent(P_b, P_Zp, P_dAnti, 405, check)
      call createCurrent(P_G0, P_GPlus, P_A, P_WMinus, 31, check)
      call createCurrent(P_Z, P_G0, 1499, check)
      call createCurrent(P_tauMinus, P_A, P_tauPlus, 75, check)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_GPlus, 1199, check)
      call createCurrent(P_tauPlus, P_nu_mu, P_WpMinus, 632, check)
      call createCurrent(P_uAnti, P_g, P_u, 26, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_G0, 356, check)
      call createCurrent(P_WPlus, P_G0, P_A, P_GMinus, 331, check)
      call createCurrent(P_GMinus, P_g, P_GPlus, P_g, 1624, check)
      call createCurrent(P_ePlus, P_A, P_eMinus, 1246, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_A, 1320, check)
      call createCurrent(P_g, P_GMinus, P_g, P_GPlus, 1581, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, 5, check)
      call createCurrent(P_b, P_H, P_bAnti, 1333, check)
      call createCurrent(P_WpPlus, P_nu_tauAnti, P_muMinus, 665, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WMinus, 608, check)
      call createCurrent(P_g, P_g, P_Zp, P_g, 1538, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_Z, 298, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_A, 755, check)
      call createCurrent(P_Zp, P_muMinus, P_tauPlus, 742, check)
      call createCurrent(P_H, P_ghWp, P_ghWpAnti, 230, check)
      call createCurrent(P_dAnti, P_d, P_G0, 1223, check)
      call createCurrent(P_sAnti, P_c, P_WpMinus, 439, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_G0, 616, check)
      call createCurrent(P_c, P_G0, P_cAnti, 718, check)
      call createCurrent(P_H, P_GMinus, P_GPlus, P_H, 194, check)
      call createCurrent(P_nu_mu, P_muPlus, P_GMinus, 812, check)
      call createCurrent(P_Z, P_H, P_WPlus, P_GMinus, 1487, check)
      call createCurrent(P_muMinus, P_muPlus, P_G0, 746, check)
      call createCurrent(P_G0, P_d, P_sAnti, 559, check)
      call createCurrent(P_g, P_A, P_g, P_g, 1580, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GPlus, 698, check)
      call createCurrent(P_g, P_dAnti, P_d, 95, check)
      call createCurrent(P_H, P_G0, P_G0, 470, check)
      call createCurrent(P_GMinus, P_WPlus, P_H, P_Z, 1114, check)
      call createCurrent(P_g, P_g, P_GMinus, P_GPlus, 1554, check)
      call createCurrent(P_uAnti, P_d, P_WPlus, 529, check)
      call createCurrent(P_A, P_Z, P_g, P_g, 1669, check)
      call createCurrent(P_A, P_GMinus, P_Z, P_GPlus, 1425, check)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_GPlus, 488, check)
      call createCurrent(P_g, P_Zp, P_g, P_A, 1673, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, 258, check)
      call createCurrent(P_bAnti, P_b, P_H, 1426, check)
      call createCurrent(P_g, P_g, P_g, P_A, 1650, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, 511, check)
      call createCurrent(P_A, P_dAnti, P_d, 650, check)
      call createCurrent(P_Z, P_H, P_GPlus, P_WMinus, 960, check)
      call createCurrent(P_WMinus, P_g, P_WpPlus, P_g, 1541, check)
      call createCurrent(P_sAnti, P_s, 1508, check)
      call createCurrent(P_c, P_sAnti, P_GMinus, 566, check)
      call createCurrent(P_H, P_WMinus, P_WPlus, P_H, 1399, check)
      call createCurrent(P_s, P_Zp, P_dAnti, 455, check)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_GMinus, 297, check)
      call createCurrent(P_tAnti, P_t, 1526, check)
      call createCurrent(P_Z, P_Z, P_G0, P_G0, 378, check)
      call createCurrent(P_muMinus, P_nu_tauAnti, P_WpPlus, 1187, check)
      call createCurrent(P_WPlus, P_GMinus, P_GPlus, P_WMinus, 1346, check)
      call createCurrent(P_u, P_uAnti, P_G0, 223, check)
      call createCurrent(P_bAnti, P_WpMinus, P_c, 955, check)
      call createCurrent(P_H, P_tAnti, P_t, 19, check)
      call createCurrent(P_t, P_G0, P_tAnti, 1035, check)
      call createCurrent(P_H, P_H, P_Z, P_Z, 281, check)
      call createCurrent(P_WPlus, P_A, P_H, P_GMinus, 725, check)
      call createCurrent(P_GMinus, P_Z, P_H, P_WPlus, 16, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, 805, check)
      call createCurrent(P_H, P_uAnti, P_u, 998, check)
      call createCurrent(P_WPlus, P_tauMinus, P_nu_tauAnti, 263, check)
      call createCurrent(P_WpPlus, P_tAnti, P_d, 927, check)
      call createCurrent(P_WpMinus, P_g, P_g, P_WpPlus, 1540, check)
      call createCurrent(P_WPlus, P_H, P_A, P_GMinus, 319, check)
      call createCurrent(P_cAnti, P_b, P_WpPlus, 133, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, 200, check)
      call createCurrent(P_t, P_H, P_tAnti, 444, check)
      call createCurrent(P_GPlus, P_GMinus, P_H, P_H, 642, check)
      call createCurrent(P_tauMinus, P_nu_eAnti, P_WpPlus, 660, check)
      call createCurrent(P_g, P_WPlus, P_g, P_WpMinus, 1584, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, 579, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_Z, 376, check)
      call createCurrent(P_t, P_GMinus, P_bAnti, 1336, check)
      call createCurrent(P_bAnti, P_WpMinus, P_u, 308, check)
      call createCurrent(P_muMinus, P_ePlus, P_Zp, 1142, check)
      call createCurrent(P_GMinus, P_Z, P_Z, P_GPlus, 576, check)
      call createCurrent(P_WPlus, P_WpMinus, P_g, P_g, 1552, check)
      call createCurrent(P_H, P_G0, P_H, P_G0, 1215, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, 1160, check)
      call createCurrent(P_ePlus, P_eMinus, P_Zp, 1244, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WMinus, 768, check)
      call createCurrent(P_G0, P_WPlus, P_A, P_GMinus, 23, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, 375, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, 341, check)
      call createCurrent(P_s, P_G0, P_dAnti, 1252, check)
      call createCurrent(P_t, P_uAnti, P_Zp, 421, check)
      call createCurrent(P_muMinus, P_GPlus, P_nu_muAnti, 726, check)
      call createCurrent(P_u, P_A, P_uAnti, 563, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, 332, check)
      call createCurrent(P_b, P_WpPlus, P_uAnti, 241, check)
      call createCurrent(P_A, P_u, P_uAnti, 910, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, 313, check)
      call createCurrent(P_GMinus, P_A, P_Z, P_GPlus, 1156, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, 1306, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, 570, check)
      call createCurrent(P_WpPlus, P_WpMinus, 1530, check)
      call createCurrent(P_G0, P_ghWm, P_ghWmAnti, 1303, check)
      call createCurrent(P_G0, P_A, P_WPlus, P_GMinus, 1112, check)
      call createCurrent(P_s, P_uAnti, P_WpPlus, 528, check)
      call createCurrent(P_WPlus, P_GMinus, P_H, P_Z, 594, check)
      call createCurrent(P_dAnti, P_GMinus, P_u, 640, check)
      call createCurrent(P_uAnti, P_GPlus, P_s, 323, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_G0, 641, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, 673, check)
      call createCurrent(P_WPlus, P_Z, P_Z, P_WMinus, 697, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_Z, 794, check)
      call createCurrent(P_GMinus, P_GPlus, P_WPlus, P_WMinus, 1344, check)
      call createCurrent(P_muMinus, P_WPlus, P_nu_muAnti, 1322, check)
      call createCurrent(P_g, P_Zp, P_A, P_g, 1665, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_A, 452, check)
      call createCurrent(P_G0, P_muMinus, P_muPlus, 1127, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WMinus, 1017, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_Z, 406, check)
      call createCurrent(P_eMinus, P_tauPlus, P_Zp, 9, check)
      call createCurrent(P_GPlus, P_H, P_WMinus, P_Z, 1131, check)
      call createCurrent(P_dAnti, P_s, P_Zp, 430, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_H, 1125, check)
      call createCurrent(P_muPlus, P_eMinus, P_Zp, 587, check)
      call createCurrent(P_GPlus, P_G0, P_G0, P_GMinus, 890, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WPlus, 56, check)
      call createCurrent(P_WPlus, P_s, P_uAnti, 1012, check)
      call createCurrent(P_Z, P_Z, P_GPlus, P_GMinus, 53, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_H, 329, check)
      call createCurrent(P_H, P_GPlus, P_Z, P_WMinus, 808, check)
      call createCurrent(P_H, P_ghWm, P_ghWmAnti, 1294, check)
      call createCurrent(P_A, P_A, P_WPlus, P_WMinus, 1339, check)
      call createCurrent(P_WpMinus, P_u, P_sAnti, 560, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_A, 1282, check)
      call createCurrent(P_g, P_g, P_G0, P_G0, 1667, check)
      call createCurrent(P_Zp, P_g, P_A, P_g, 1668, check)
      call createCurrent(P_WpMinus, P_t, P_sAnti, 86, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, 1288, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, 991, check)
      call createCurrent(P_GPlus, P_muMinus, P_nu_muAnti, 1072, check)
      call createCurrent(P_g, P_g, P_Z, P_g, 1628, check)
      call createCurrent(P_WpMinus, P_nu_tau, P_ePlus, 913, check)
      call createCurrent(P_muMinus, P_A, P_muPlus, 744, check)
      call createCurrent(P_u, P_uAnti, P_H, 45, check)
      call createCurrent(P_muPlus, P_WMinus, P_nu_mu, 1104, check)
      call createCurrent(P_g, P_Zp, P_g, P_g, 1618, check)
      call createCurrent(P_G0, P_s, P_dAnti, 619, check)
      call createCurrent(P_eMinus, P_Zp, P_tauPlus, 823, check)
      call createCurrent(P_u, P_WMinus, P_sAnti, 1141, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, 211, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_Z, 1486, check)
      call createCurrent(P_g, P_A, P_g, P_A, 1619, check)
      call createCurrent(P_tauMinus, P_WpPlus, P_nu_muAnti, 42, check)
      call createCurrent(P_b, P_bAnti, P_H, 1175, check)
      call createCurrent(P_ePlus, P_WMinus, P_nu_e, 846, check)
      call createCurrent(P_WMinus, P_WPlus, P_H, P_H, 1077, check)
      call createCurrent(P_d, P_dAnti, P_g, 1307, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WpPlus, 22, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, 492, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_A, 1002, check)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_GPlus, 796, check)
      call createCurrent(P_b, P_Zp, P_bAnti, 522, check)
      call createCurrent(P_GMinus, P_GPlus, P_WMinus, P_WPlus, 1154, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, 1432, check)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_GMinus, 1042, check)
      call createCurrent(P_ghWm, P_H, P_ghWmAnti, 989, check)
      call createCurrent(P_g, P_G0, P_G0, P_g, 1591, check)
      call createCurrent(P_g, P_A, P_Z, P_g, 1659, check)
      call createCurrent(P_ePlus, P_eMinus, P_Z, 112, check)
      call createCurrent(P_tAnti, P_Zp, P_u, 109, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, 803, check)
      call createCurrent(P_u, P_WpMinus, P_sAnti, 1444, check)
      call createCurrent(P_ePlus, P_tauMinus, P_Zp, 277, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_H, 1128, check)
      call createCurrent(P_Z, P_WPlus, P_H, P_GMinus, 537, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_H, 116, check)
      call createCurrent(P_c, P_g, P_cAnti, 303, check)
      call createCurrent(P_c, P_cAnti, P_Z, 127, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, 138, check)
      call createCurrent(P_GPlus, P_GMinus, P_WMinus, P_WPlus, 981, check)
      call createCurrent(P_WPlus, P_WMinus, P_H, 472, check)
      call createCurrent(P_dAnti, P_Z, P_d, 855, check)
      call createCurrent(P_u, P_bAnti, P_WpMinus, 1205, check)
      call createCurrent(P_ePlus, P_nu_mu, P_WpMinus, 184, check)
      call createCurrent(P_g, P_ghG, P_ghGAnti, 838, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, 728, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_G0, 478, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_Z, 117, check)
      call createCurrent(P_sAnti, P_WMinus, P_c, 1485, check)
      call createCurrent(P_uAnti, P_u, P_G0, 1139, check)
      call createCurrent(P_GPlus, P_tAnti, P_b, 1015, check)
      call createCurrent(P_H, P_H, P_GMinus, P_GPlus, 591, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_H, 562, check)
      call createCurrent(P_tauMinus, P_muPlus, P_Zp, 574, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, 7, check)
      call createCurrent(P_Z, P_GPlus, P_G0, P_WMinus, 933, check)
      call createCurrent(P_d, P_tAnti, P_WpPlus, 453, check)
      call createCurrent(P_dAnti, P_b, P_Zp, 407, check)
      call createCurrent(P_uAnti, P_H, P_u, 397, check)
      call createCurrent(P_g, P_WpPlus, P_WMinus, P_g, 1622, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_A, 408, check)
      call createCurrent(P_WpPlus, P_nu_muAnti, P_muMinus, 799, check)
      call createCurrent(P_nu_eAnti, P_tauMinus, P_WpPlus, 635, check)
      call createCurrent(P_WMinus, P_Z, P_Z, P_WPlus, 209, check)
      call createCurrent(P_WPlus, P_g, P_g, P_WMinus, 1603, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, 404, check)
      call createCurrent(P_WPlus, P_muMinus, P_nu_muAnti, 502, check)
      call createCurrent(P_Zp, P_bAnti, P_b, 418, check)
      call createCurrent(P_eMinus, P_Zp, P_muPlus, 542, check)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_GPlus, 781, check)
      call createCurrent(P_WpMinus, P_nu_mu, P_muPlus, 1123, check)
      call createCurrent(P_tauPlus, P_Zp, P_eMinus, 987, check)
      call createCurrent(P_A, P_A, P_g, P_g, 1593, check)
      call createCurrent(P_g, P_A, P_g, P_Zp, 1655, check)
      call createCurrent(P_tauPlus, P_nu_e, P_WpMinus, 368, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, 1177, check)
      call createCurrent(P_dAnti, P_u, P_WpMinus, 835, check)
      call createCurrent(P_b, P_bAnti, P_Z, 515, check)
      call createCurrent(P_nu_tau, P_WpMinus, P_muPlus, 648, check)
      call createCurrent(P_Zp, P_uAnti, P_t, 879, check)
      call createCurrent(P_Z, P_Z, 1531, check)
      call createCurrent(P_A, P_eMinus, P_ePlus, 1074, check)
      call createCurrent(P_b, P_sAnti, P_Zp, 238, check)
      call createCurrent(P_H, P_GPlus, P_GMinus, 860, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, 520, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_A, 252, check)
      call createCurrent(P_t, P_bAnti, P_WpMinus, 469, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, 1381, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, 54, check)
      call createCurrent(P_sAnti, P_Zp, P_d, 60, check)
      call createCurrent(P_nu_tauAnti, P_muMinus, P_WpPlus, 737, check)
      call createCurrent(P_Z, P_sAnti, P_s, 1448, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, 610, check)
      call createCurrent(P_Zp, P_g, P_g, P_Zp, 1663, check)
      call createCurrent(P_G0, P_WMinus, P_A, P_GPlus, 871, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Zp, 290, check)
      call createCurrent(P_tAnti, P_s, P_WpPlus, 825, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, 321, check)
      call createCurrent(P_Z, P_G0, P_G0, P_Z, 485, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_Z, 519, check)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_G0, 645, check)
      call createCurrent(P_t, P_Zp, P_tAnti, 1434, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, 977, check)
      call createCurrent(P_eMinus, P_nu_muAnti, P_WpPlus, 233, check)
      call createCurrent(P_GMinus, P_H, P_WPlus, 965, check)
      call createCurrent(P_s, P_uAnti, P_WPlus, 1345, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, 967, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_A, 1355, check)
      call createCurrent(P_nu_muAnti, P_Z, P_nu_mu, 1122, check)
      call createCurrent(P_G0, P_G0, P_GMinus, P_GPlus, 273, check)
      call createCurrent(P_WpMinus, P_muPlus, P_nu_tau, 1379, check)
      call createCurrent(P_GPlus, P_GMinus, P_H, 1441, check)
      call createCurrent(P_GPlus, P_nu_eAnti, P_eMinus, 282, check)
      call createCurrent(P_u, P_Zp, P_uAnti, 275, check)
      call createCurrent(P_WpPlus, P_nu_muAnti, P_tauMinus, 1276, check)
      call createCurrent(P_WMinus, P_g, P_g, P_WPlus, 1607, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_A, 639, check)
      call createCurrent(P_muMinus, P_WpPlus, P_nu_eAnti, 1203, check)
      call createCurrent(P_c, P_Zp, P_uAnti, 703, check)
      call createCurrent(P_WMinus, P_H, P_A, P_GPlus, 787, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_Z, 471, check)
      call createCurrent(P_WMinus, P_Z, P_G0, P_GPlus, 691, check)
      call createCurrent(P_cAnti, P_G0, P_c, 1442, check)
      call createCurrent(P_WpMinus, P_dAnti, P_u, 516, check)
      call createCurrent(P_H, P_A, P_GPlus, P_WMinus, 1111, check)
      call createCurrent(P_c, P_GMinus, P_sAnti, 839, check)
      call createCurrent(P_Zp, P_tauMinus, P_muPlus, 1235, check)
      call createCurrent(P_WPlus, P_s, P_cAnti, 181, check)
      call createCurrent(P_WMinus, P_WPlus, 1520, check)
      call createCurrent(P_H, P_eMinus, P_ePlus, 103, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, 1296, check)
      call createCurrent(P_H, P_H, P_H, P_H, 544, check)
      call createCurrent(P_WpPlus, P_d, P_uAnti, 509, check)
      call createCurrent(P_G0, P_GMinus, P_G0, P_GPlus, 347, check)
      call createCurrent(P_Z, P_g, P_g, P_g, 1680, check)
      call createCurrent(P_Z, P_Z, P_H, P_H, 598, check)
      call createCurrent(P_g, P_s, P_sAnti, 135, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_H, 1179, check)
      call createCurrent(P_Zp, P_muPlus, P_tauMinus, 314, check)
      call createCurrent(P_eMinus, P_G0, P_ePlus, 831, check)
      call createCurrent(P_WpMinus, P_c, P_dAnti, 183, check)
      call createCurrent(P_WMinus, P_A, P_H, P_GPlus, 828, check)
      call createCurrent(P_G0, P_WPlus, P_G0, P_WMinus, 4, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, 1437, check)
      call createCurrent(P_c, P_A, P_cAnti, 179, check)
      call createCurrent(P_Zp, P_b, P_sAnti, 736, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, 784, check)
      call createCurrent(P_GPlus, P_Z, P_G0, P_WMinus, 129, check)
      call createCurrent(P_Z, P_g, P_Zp, P_g, 1586, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Zp, 94, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_A, 546, check)
      call createCurrent(P_tauPlus, P_Z, P_tauMinus, 388, check)
      call createCurrent(P_WpMinus, P_ePlus, P_nu_mu, 936, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_G0, 58, check)
      call createCurrent(P_A, P_G0, P_GPlus, P_WMinus, 248, check)
      call createCurrent(P_Z, P_WMinus, P_A, P_WPlus, 1364, check)
      call createCurrent(P_Zp, P_c, P_cAnti, 10, check)
      call createCurrent(P_cAnti, P_WPlus, P_d, 850, check)
      call createCurrent(P_bAnti, P_b, 1537, check)
      call createCurrent(P_g, P_g, P_g, 24, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, 1300, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, 791, check)
      call createCurrent(P_eMinus, P_WpPlus, P_nu_muAnti, 1463, check)
      call createCurrent(P_GMinus, P_g, P_g, P_GPlus, 1632, check)
      call createCurrent(P_muPlus, P_nu_e, P_WpMinus, 1010, check)
      call createCurrent(P_t, P_tAnti, P_Z, 567, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, 234, check)
      call createCurrent(P_nu_tau, P_muPlus, P_WpMinus, 490, check)
      call createCurrent(P_H, P_WPlus, P_A, P_GMinus, 692, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_G0, 969, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_Z, 1047, check)
      call createCurrent(P_Z, P_nu_e, P_nu_eAnti, 654, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, 1267, check)
      call createCurrent(P_A, P_muMinus, P_muPlus, 609, check)
      call createCurrent(P_GMinus, P_WMinus, P_GPlus, P_WPlus, 774, check)
      call createCurrent(P_GMinus, P_GPlus, P_g, P_g, 1642, check)
      call createCurrent(P_bAnti, P_u, P_WpMinus, 622, check)
      call createCurrent(P_ePlus, P_Zp, P_muMinus, 694, check)
      call createCurrent(P_H, P_ePlus, P_eMinus, 912, check)
      call createCurrent(P_WpMinus, P_g, P_WpPlus, P_g, 1662, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_H, 552, check)
      call createCurrent(P_ePlus, P_Z, P_eMinus, 1210, check)
      call createCurrent(P_u, P_WpMinus, P_bAnti, 681, check)
      call createCurrent(P_g, P_g, P_A, P_Zp, 1579, check)
      call createCurrent(P_WpPlus, P_s, P_uAnti, 1037, check)
      call createCurrent(P_nu_muAnti, P_WpPlus, P_tauMinus, 756, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, 894, check)
      call createCurrent(P_nu_e, P_Z, P_nu_eAnti, 390, check)
      call createCurrent(P_dAnti, P_u, P_WMinus, 147, check)
      call createCurrent(P_uAnti, P_d, P_GPlus, 1450, check)
      call createCurrent(P_s, P_sAnti, P_G0, 446, check)
      call createCurrent(P_dAnti, P_H, P_s, 1361, check)
      call createCurrent(P_g, P_g, P_GPlus, P_GMinus, 1648, check)
      call createCurrent(P_GMinus, P_H, P_Z, P_WPlus, 1113, check)
      call createCurrent(P_H, P_WPlus, P_Z, P_GMinus, 151, check)
      call createCurrent(P_u, P_WpMinus, P_dAnti, 1224, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, 1340, check)
      call createCurrent(P_ePlus, P_H, P_eMinus, 1389, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GPlus, 307, check)
      call createCurrent(P_sAnti, P_H, P_d, 1183, check)
      call createCurrent(P_u, P_H, P_uAnti, 558, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_Z, 753, check)
      call createCurrent(P_Z, P_t, P_tAnti, 1352, check)
      call createCurrent(P_nu_e, P_ePlus, P_GMinus, 1405, check)
      call createCurrent(P_ePlus, P_muMinus, P_Zp, 939, check)
      call createCurrent(P_Z, P_c, P_cAnti, 606, check)
      call createCurrent(P_tAnti, P_b, P_GPlus, 864, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_A, 905, check)
      call createCurrent(P_H, P_GPlus, P_H, P_GMinus, 126, check)
      call createCurrent(P_sAnti, P_G0, P_d, 450, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_GMinus, 590, check)
      call createCurrent(P_b, P_g, P_bAnti, 893, check)
      call createCurrent(P_WPlus, P_G0, P_G0, P_WMinus, 602, check)
      call createCurrent(P_WPlus, P_H, P_WMinus, P_H, 1198, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, 97, check)
      call createCurrent(P_muMinus, P_Zp, P_muPlus, 1493, check)
      call createCurrent(P_ePlus, P_G0, P_eMinus, 779, check)
      call createCurrent(P_H, P_GMinus, P_GPlus, 809, check)
      call createCurrent(P_sAnti, P_WpMinus, P_t, 973, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, 1480, check)
      call createCurrent(P_c, P_Zp, P_tAnti, 1230, check)
      call createCurrent(P_WMinus, P_tauPlus, P_nu_tau, 1024, check)
      call createCurrent(P_WPlus, P_nu_tauAnti, P_tauMinus, 1140, check)
      call createCurrent(P_WpPlus, P_b, P_uAnti, 382, check)
      call createCurrent(P_ePlus, P_GMinus, P_nu_e, 1178, check)
      call createCurrent(P_WpPlus, P_muMinus, P_nu_tauAnti, 1412, check)
      call createCurrent(P_g, P_g, P_Z, P_A, 1630, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, 1243, check)
      call createCurrent(P_WpPlus, P_tauMinus, P_nu_muAnti, 253, check)
      call createCurrent(P_H, P_dAnti, P_d, 1382, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_A, 1329, check)
      call createCurrent(P_WpPlus, P_d, P_cAnti, 1216, check)
      call createCurrent(P_muPlus, P_muMinus, P_Z, 766, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, 1386, check)
      call createCurrent(P_H, P_c, P_cAnti, 346, check)
      call createCurrent(P_Z, P_G0, P_H, 1458, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WpPlus, 627, check)
      call createCurrent(P_GMinus, P_t, P_bAnti, 245, check)
      call createCurrent(P_Zp, P_sAnti, P_d, 503, check)
      call createCurrent(P_d, P_Z, P_dAnti, 108, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_H, 334, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, 500, check)
      call createCurrent(P_Z, P_Z, P_WMinus, P_WPlus, 952, check)
      call createCurrent(P_t, P_A, P_tAnti, 1033, check)
      call createCurrent(P_GPlus, P_WMinus, P_H, P_A, 999, check)
      call createCurrent(P_G0, P_Z, P_H, 962, check)
      call createCurrent(P_cAnti, P_c, P_Z, 1181, check)
      call createCurrent(P_uAnti, P_u, P_H, 604, check)
      call createCurrent(P_GMinus, P_sAnti, P_c, 1367, check)
      call createCurrent(P_ghZ, P_H, P_ghZAnti, 816, check)
      call createCurrent(P_A, P_tauMinus, P_tauPlus, 1051, check)
      call createCurrent(P_uAnti, P_WpPlus, P_b, 274, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_G0, 763, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, 394, check)
      call createCurrent(P_A, P_G0, P_GMinus, P_WPlus, 1102, check)
      call createCurrent(P_g, P_g, P_WMinus, P_WpPlus, 1678, check)
      call createCurrent(P_WpMinus, P_nu_e, P_tauPlus, 715, check)
      call createCurrent(P_H, P_H, P_WPlus, P_WMinus, 739, check)
      call createCurrent(P_Z, P_GPlus, P_A, P_GMinus, 906, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_Z, 150, check)
      call createCurrent(P_g, P_WPlus, P_g, P_WMinus, 1610, check)
      call createCurrent(P_d, P_dAnti, P_Zp, 1374, check)
      call createCurrent(P_g, P_g, P_WpMinus, P_WPlus, 1539, check)
      call createCurrent(P_dAnti, P_G0, P_d, 292, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Z, 1438, check)
      call createCurrent(P_A, P_A, 1529, check)
      call createCurrent(P_g, P_ghGAnti, P_ghG, 178, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, 757, check)
      call createCurrent(P_muMinus, P_muPlus, P_Z, 419, check)
      call createCurrent(P_eMinus, P_Z, P_ePlus, 1401, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_G0, 434, check)
      call createCurrent(P_WPlus, P_cAnti, P_s, 219, check)
      call createCurrent(P_cAnti, P_d, P_WpPlus, 1078, check)
      call createCurrent(P_cAnti, P_c, P_H, 1482, check)
      call createCurrent(P_Zp, P_tauPlus, P_muMinus, 699, check)
      call createCurrent(P_tAnti, P_g, P_t, 1466, check)
      call createCurrent(P_t, P_WpMinus, P_bAnti, 454, check)
      call createCurrent(P_GMinus, P_Z, P_G0, P_WPlus, 582, check)
      call createCurrent(P_H, P_A, P_WPlus, P_GMinus, 1209, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, 747, check)
      call createCurrent(P_WMinus, P_WMinus, P_WPlus, P_WPlus, 997, check)
      call createCurrent(P_u, P_uAnti, P_A, 136, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_H, 101, check)
      call createCurrent(P_A, P_Z, P_GMinus, P_GPlus, 646, check)
      call createCurrent(P_t, P_cAnti, P_Zp, 710, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_Z, 361, check)
      call createCurrent(P_g, P_Z, P_g, P_g, 1637, check)
      call createCurrent(P_WMinus, P_sAnti, P_u, 77, check)
      call createCurrent(P_A, P_WPlus, P_A, P_WMinus, 833, check)
      call createCurrent(P_muMinus, P_tauPlus, P_Zp, 1247, check)
      call createCurrent(P_nu_muAnti, P_tauMinus, P_WpPlus, 1242, check)
      call createCurrent(P_WPlus, P_H, P_WMinus, 1107, check)
      call createCurrent(P_Zp, P_g, P_g, P_A, 1679, check)
      call createCurrent(P_g, P_WpMinus, P_WPlus, P_g, 1614, check)
      call createCurrent(P_Z, P_WMinus, P_H, P_GPlus, 793, check)
      call createCurrent(P_G0, P_ePlus, P_eMinus, 565, check)
      call createCurrent(P_G0, P_G0, P_g, P_g, 1547, check)
      call createCurrent(P_d, P_Zp, P_dAnti, 1184, check)
      call createCurrent(P_WpPlus, P_eMinus, P_nu_muAnti, 1197, check)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_GPlus, 80, check)
    end subroutine createCurrents

    subroutine check_vertices_mdl()
      call createCurrents(.true.)
    end subroutine check_vertices_mdl

    subroutine get_vertex_lorentz_rank_mdl(ty,cc,mr)
      integer, intent(in) :: ty
      logical, intent(in) :: cc(0:)
      integer, intent(out) :: mr
      select case(ty)
      case(4)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(5)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(10)
        if (cc(1) .or. cc(2)) then
          mr = 1
        else
          mr = 0
        end if 
      case(19)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(21)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(22)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(23)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(25)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(26)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(27)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(29)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(30)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(31)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(43)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(44)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(45)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(46)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(47)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(48)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(49)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(51)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(52)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(53)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(54)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(57)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(61)
        if (cc(1) .or. cc(2)) then
          mr = 1
        else
          mr = 0
        end if 
      case(64)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(67)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(68)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(70)
        if (cc(1) .or. cc(2)) then
          mr = 1
        else
          mr = 0
        end if 
      case default
        mr = 0
      end select 
    end subroutine get_vertex_lorentz_rank_mdl
end module class_vertices
